@@ -230,11 +230,12 @@ const fetchNodeMetrics = (): Promise<NodeMetrics> => {
     },
     {
       key: 'usedStorage',
-      query: 'sum by (instance) (node_filesystem_size_bytes - node_filesystem_free_bytes)',
+      query:
+        'sum by (instance) (node_filesystem_size_bytes{mountpoint="/var"} - node_filesystem_free_bytes{mountpoint="/var"})',
     },
     {
       key: 'totalStorage',
-      query: 'sum by (instance) (node_filesystem_size_bytes)',
+      query: 'sum by (instance) (node_filesystem_size_bytes{mountpoint="/var"})',
     },
     {
       key: 'cpu',
