@@ -1,5 +1,5 @@
 import { K8sResourceKindReference } from '@console/internal/module/k8s';
-import { Extension } from './extension';
+import { Extension } from './base';
 
 namespace ExtensionProperties {
   export interface ClusterServiceVersionAction {
@@ -11,6 +11,8 @@ namespace ExtensionProperties {
     apiGroup: string;
     /** action callback */
     callback: (kind: K8sResourceKindReference, obj: any) => () => any;
+    required?: string[];
+    disallowed?: string[];
   }
 }
 
