@@ -1,8 +1,6 @@
-export * from './extension';
-export * from './types';
-
-// TODO(vojtech): internal code needed by plugin SDK should be moved to console-shared package
+export * from './base';
 
+// specific extension types
 export * from './dashboards';
 export * from './features';
 export * from './kebab-actions';
@@ -16,3 +14,4 @@ export * from './global-configs';
 export * from './clusterserviceversions';
 export * from './dev-catalog';
 export * from './reducers';
+export * from './horizontal-nav';
