@@ -8,3 +8,5 @@ export * from './status';
 export * from './pod';
 export * from './popper';
 export * from './shortcuts';
+export * from './drawer';
+export * from './health-checks';
