@@ -7,8 +7,10 @@ const log = (x: number, y: number) => {
 };
 
 // Get the larget unit seen in the dataframe within the supported range
-const bestUnit = (dataPoints: DataPoint[], type) => {
-  const bestLevel = dataPoints.reduce((maxUnit, point) => {
+const bestUnit = (dataPoints: DataPoint[][], type) => {
+  const flattenDataPoints = dataPoints.reduce((acc, arr) => acc.concat(arr), []);
+
+  const bestLevel = flattenDataPoints.reduce((maxUnit, point) => {
     const index = Math.floor(log(_.get(type, 'divisor', 1024), point.y));
     const unitIndex = index >= type.units.length ? type.units.length - 1 : index;
     return maxUnit < unitIndex ? unitIndex : maxUnit;
@@ -17,22 +19,24 @@ const bestUnit = (dataPoints: DataPoint[], type) => {
 };
 
 // Array based procssor
-export const processFrame = (dataPoints: DataPoint[], typeName: string): ProcessFrameResult => {
+export const processFrame = (dataPoints: DataPoint[][], typeName: string): ProcessFrameResult => {
   const type = getType(typeName);
   let unit = null;
-  if (dataPoints) {
+  if (dataPoints && dataPoints[0]) {
     // Get the appropriate unit and convert the dataset to that level
     unit = bestUnit(dataPoints, type);
     const frameLevel = type.units.indexOf(unit);
-    dataPoints.forEach((point) => {
-      point.y /= type.divisor ** frameLevel;
-    });
+    dataPoints.forEach((arr) =>
+      arr.forEach((point) => {
+        point.y /= type.divisor ** frameLevel;
+      }),
+    );
   }
   return { processedData: dataPoints, unit };
 };
 
 export type ProcessFrameResult = {
-  processedData: DataPoint[];
+  processedData: DataPoint[][];
   unit: string;
 };
 
