@@ -11,7 +11,7 @@ import {
 import { Map as ImmutableMap } from 'immutable';
 import { ImageManifestVuln } from './types';
 
-export const SecurityLabellerFlag = 'SECURITY_LABELLER';
+export const ContainerSecurityFlag = 'SECURITY_LABELLER';
 
 export enum Priority {
   Defcon1 = 'Defcon1',
@@ -125,3 +125,6 @@ export const totalFor = (priority: Priority) => (obj: ImageManifestVuln) => {
       return 0;
   }
 };
+
+export const priorityFor = (severity: string) =>
+  vulnPriority.find(({ title }) => title === severity) || vulnPriority.get(Priority.Unknown);
