@@ -1,12 +1,13 @@
 import * as React from 'react';
+import { useField } from 'formik';
 import { connectToFlags, FlagsObject } from '@console/internal/reducers/features';
 import { K8sKind } from '@console/internal/module/k8s';
 import { DeploymentModel, DeploymentConfigModel } from '@console/internal/models';
-import { RadioButtonField, RadioOption } from '@console/shared';
 import { FLAG_KNATIVE_SERVING_SERVICE, ServiceModel } from '@console/knative-plugin';
+import { RadioGroupField, RadioGroupOption } from '@console/shared';
 import { useAccessReview } from '@console/internal/components/utils';
 import { getActiveNamespace } from '@console/internal/actions/ui';
-import { Resources } from '../import-types';
+import { Resources, ReadableResourcesNames } from '../import-types';
 import FormSection from './FormSection';
 import './ResourceSection.scss';
 
@@ -26,25 +27,31 @@ const createHelpText = (k8sModel: K8sKind, helpText: string) => {
 };
 
 const ResourceSection: React.FC<ResourceSectionProps> = ({ flags }) => {
-  const radioOptions: RadioOption[] = [
-    {
-      label: DeploymentModel.label,
+  const [field] = useField<Resources[]>('resourceTypesNotValid');
+  const invalidTypes = field.value || [];
+
+  const radioOptions: RadioGroupOption[] = [];
+  if (!invalidTypes.includes(Resources.Kubernetes)) {
+    radioOptions.push({
+      label: ReadableResourcesNames[Resources.Kubernetes],
       value: Resources.Kubernetes,
       children: createHelpText(
         DeploymentModel,
         `A ${DeploymentModel.label} enables declarative updates for Pods and ReplicaSets.`,
       ),
-    },
-    {
-      label: DeploymentConfigModel.label,
+    });
+  }
+  if (!invalidTypes.includes(Resources.OpenShift)) {
+    radioOptions.push({
+      label: ReadableResourcesNames[Resources.OpenShift],
       value: Resources.OpenShift,
       children: createHelpText(
         DeploymentConfigModel,
         `A ${DeploymentConfigModel.label} defines the template for a pod \
         and manages deploying new images or configuration changes`,
       ),
-    },
-  ];
+    });
+  }
 
   const knativeServiceAccess = useAccessReview({
     group: ServiceModel.apiGroup,
@@ -52,10 +59,13 @@ const ResourceSection: React.FC<ResourceSectionProps> = ({ flags }) => {
     namespace: getActiveNamespace(),
     verb: 'create',
   });
-
-  if (flags[FLAG_KNATIVE_SERVING_SERVICE] && knativeServiceAccess) {
+  const canIncludeKnative =
+    !invalidTypes.includes(Resources.KnativeService) &&
+    flags[FLAG_KNATIVE_SERVING_SERVICE] &&
+    knativeServiceAccess;
+  if (canIncludeKnative) {
     radioOptions.push({
-      label: 'Knative Service',
+      label: ReadableResourcesNames[Resources.KnativeService],
       value: Resources.KnativeService,
       children: createHelpText(ServiceModel, `A Knative Service enables scaling to zero when idle`),
     });
@@ -63,7 +73,7 @@ const ResourceSection: React.FC<ResourceSectionProps> = ({ flags }) => {
   return (
     <FormSection title="Resources" fullWidth>
       <div>Select the resource type to generate</div>
-      <RadioButtonField name="resources" options={radioOptions} />
+      <RadioGroupField name="resources" options={radioOptions} />
     </FormSection>
   );
 };
