@@ -1,6 +1,7 @@
 import * as React from 'react';
 import { RouteComponentProps } from 'react-router';
 import { getBadgeFromType } from '@console/shared';
+import { withStartGuide } from '@console/internal/components/start-guide';
 import { PipelineModel } from '../../models';
 import ProjectListPage from '../projects/ProjectListPage';
 import PipelinesResourceList from './PipelinesResourceList';
@@ -14,12 +15,14 @@ export const PipelinesPage: React.FC<PipelinesPageProps> = (props) => {
     },
   } = props;
   return namespace ? (
-    <PipelinesResourceList
-      {...props}
-      badge={getBadgeFromType(PipelineModel.badge)}
-      namespace={namespace}
-      title={PipelineModel.labelPlural}
-    />
+    <div>
+      <PipelinesResourceList
+        {...props}
+        badge={getBadgeFromType(PipelineModel.badge)}
+        namespace={namespace}
+        title={PipelineModel.labelPlural}
+      />
+    </div>
   ) : (
     <ProjectListPage
       title={PipelineModel.labelPlural}
@@ -30,4 +33,4 @@ export const PipelinesPage: React.FC<PipelinesPageProps> = (props) => {
   );
 };
 
-export default PipelinesPage;
+export default withStartGuide(PipelinesPage);
