@@ -6,7 +6,7 @@ import {
 } from '@console/internal/components/factory/modal';
 import { errorModal } from '@console/internal/components/modals';
 import { Pipeline, PipelineRun, PipelineWorkspace } from '../../../../utils/pipeline-augment';
-import { useUserLabelForManualStart } from '../../../pipelineruns/triggered-by';
+import { useUserAnnotationForManualStart } from '../../../pipelineruns/triggered-by';
 import ModalStructure from '../common/ModalStructure';
 import { convertPipelineToModalData } from '../common/utils';
 import { startPipelineSchema } from '../common/validation-utils';
@@ -23,7 +23,7 @@ const StartPipelineModal: React.FC<StartPipelineModalProps & ModalComponentProps
   close,
   onSubmit,
 }) => {
-  const userStartedLabel = useUserLabelForManualStart();
+  const userStartedAnnotation = useUserAnnotationForManualStart();
 
   const initialValues: StartPipelineFormValues = {
     ...convertPipelineToModalData(pipeline),
@@ -38,7 +38,7 @@ const StartPipelineModal: React.FC<StartPipelineModalProps & ModalComponentProps
   const handleSubmit = (values: StartPipelineFormValues, actions): void => {
     actions.setSubmitting(true);
 
-    submitStartPipeline(values, pipeline, userStartedLabel)
+    submitStartPipeline(values, pipeline, null, userStartedAnnotation)
       .then((res) => {
         actions.setSubmitting(false);
         onSubmit && onSubmit(res);
