@@ -72,13 +72,14 @@ const mapStitchReplaceInOthers = <TaskType extends PipelineBuilderTaskBase>(
   }
 
   const updatedIterationTask = mapRemoveRelatedInOthers(removalTask.name, iterationTask);
+  let newRunAfter: string[] = removalTask.runAfter;
   if (updatedIterationTask.runAfter.length > 0) {
-    return updatedIterationTask;
+    newRunAfter = [...updatedIterationTask.runAfter, ...newRunAfter];
   }
 
   return {
     ...updatedIterationTask,
-    runAfter: removalTask.runAfter,
+    runAfter: newRunAfter,
   };
 };
 
@@ -127,11 +128,11 @@ const getErrors = (task: PipelineTask, resource: PipelineResourceTask): TaskErro
   const resources = getTaskResources(resource);
 
   const taskInputResources = task.resources?.inputs?.length || 0;
-  const requiredInputResources = resources.inputs?.length || 0;
+  const requiredInputResources = (resources.inputs || []).filter((r) => !r?.optional).length;
   const missingInputResources = requiredInputResources - taskInputResources > 0;
 
   const taskOutputResources = task.resources?.outputs?.length || 0;
-  const requiredOutputResources = resources.outputs?.length || 0;
+  const requiredOutputResources = (resources.outputs || []).filter((r) => !r?.optional).length;
   const missingOutputResources = requiredOutputResources - taskOutputResources > 0;
 
   const errorListing: TaskErrorType[] = [];
@@ -200,14 +201,16 @@ const addListNode: UpdateOperationAction<UpdateOperationAddData> = (tasks, listT
   }
 };
 
+const getTaskNames = (tasks: PipelineTask[]) => tasks.map((t) => t.name);
+
 const convertListToTask: UpdateOperationAction<UpdateOperationConvertToTaskData> = (
   tasks,
   listTasks,
   data,
 ) => {
   const { name, resource, runAfter } = data;
-
-  const newPipelineTask: PipelineTask = convertResourceToTask(resource, runAfter);
+  const usedNames = getTaskNames(tasks);
+  const newPipelineTask: PipelineTask = convertResourceToTask(usedNames, resource, runAfter);
 
   return {
     tasks: [
@@ -383,8 +386,8 @@ const fixInvalidListTask: UpdateOperationAction<UpdateOperationFixInvalidTaskLis
   data,
 ) => {
   const { existingName, resource, runAfter } = data;
-
-  const newPipelineTask: PipelineTask = convertResourceToTask(resource, runAfter);
+  const usedNames = getTaskNames(tasks);
+  const newPipelineTask: PipelineTask = convertResourceToTask(usedNames, resource, runAfter);
 
   return {
     tasks: [
