@@ -2,18 +2,20 @@ import * as React from 'react';
 import { TextInputTypes } from '@patternfly/react-core';
 import { InputField } from '@console/shared';
 
-const PipelineGitOptions: React.FC = () => (
+type PipelineGitOptionsProps = { prefixName: string };
+
+const PipelineGitOptions: React.FC<PipelineGitOptionsProps> = ({ prefixName }) => (
   <>
     <InputField
       type={TextInputTypes.text}
-      name="params.url"
+      name={`${prefixName}.params.url`}
       label="URL"
       helpText="Please provide git URL."
       required
     />
     <InputField
       type={TextInputTypes.text}
-      name="params.revision"
+      name={`${prefixName}.params.revision`}
       label="Revision"
       helpText="Please provide Revisions. i.e master"
     />
