@@ -2,7 +2,9 @@ import * as React from 'react';
 import { ResourceOverviewPage } from '@console/internal/components/overview/resource-overview-page';
 import * as _ from 'lodash';
 import KnativeResourceOverviewPage from '@console/knative-plugin/src/components/overview/KnativeResourceOverviewPage';
+import { KebabAction } from '@console/internal/components/utils';
 import { TopologyDataObject } from './topology-types';
+import { ModifyApplication } from '../../actions/modify-application';
 
 export type TopologyResourcePanelProps = {
   item: TopologyDataObject;
@@ -15,11 +17,18 @@ const TopologyResourcePanel: React.FC<TopologyResourcePanelProps> = ({ item }) =
   if (_.get(item, 'data.isKnativeResource', false) && itemKind && itemKind !== 'Deployment') {
     return <KnativeResourceOverviewPage item={item.resources} />;
   }
+
+  let customActions: KebabAction[] = null;
+  if (!item.operatorBackedService) {
+    customActions = [ModifyApplication];
+  }
+
   return (
     resourceItemToShowOnSideBar && (
       <ResourceOverviewPage
         item={resourceItemToShowOnSideBar}
         kind={resourceItemToShowOnSideBar.obj.kind}
+        customActions={customActions}
       />
     )
   );
