@@ -1,30 +1,24 @@
 import * as React from 'react';
 import * as classNames from 'classnames';
-import { connect } from 'react-redux';
-import { RootState } from '@console/internal/redux';
 import { GraphComponent as BaseGraphComponent, WithContextMenuProps } from '@console/topology';
-import { TopologyFilters, getTopologyFilters } from '../filters/filter-utils';
 
 type GraphComponentProps = React.ComponentProps<typeof BaseGraphComponent> & {
   dragEditInProgress?: boolean;
   hasDropTarget?: boolean;
   dragCreate?: boolean;
-  filters: TopologyFilters;
 } & WithContextMenuProps;
 
 const DRAG_ACTIVE_CLASS = 'odc-m-drag-active';
-const FILTER_ACTIVE_CLASS = 'odc-m-filter-active';
 const VALID_DROP_CLASS = 'odc-m-valid-drop-target';
 
 const GraphComponent: React.FC<GraphComponentProps> = (props) => {
-  const { dragEditInProgress, hasDropTarget, dragCreate, filters } = props;
+  const { dragEditInProgress, hasDropTarget, dragCreate } = props;
   const graphClasses = classNames('odc-graph', { 'odc-m-drag-create': dragCreate });
+
   React.useEffect(() => {
     const addClassList = [];
     const removeClassList = [];
-    filters.searchQuery.trim() !== ''
-      ? addClassList.push(FILTER_ACTIVE_CLASS)
-      : removeClassList.push(FILTER_ACTIVE_CLASS);
+
     dragEditInProgress
       ? addClassList.push(DRAG_ACTIVE_CLASS)
       : removeClassList.push(DRAG_ACTIVE_CLASS);
@@ -36,7 +30,7 @@ const GraphComponent: React.FC<GraphComponentProps> = (props) => {
     if (removeClassList.length) {
       removeClassList.forEach((className) => document.body.classList.remove(className));
     }
-  }, [dragEditInProgress, filters.searchQuery, hasDropTarget]);
+  }, [dragEditInProgress, hasDropTarget]);
   return (
     <g className={graphClasses}>
       <BaseGraphComponent {...props} />
@@ -44,8 +38,4 @@ const GraphComponent: React.FC<GraphComponentProps> = (props) => {
   );
 };
 
-const GraphComponentState = (state: RootState) => {
-  const filters = getTopologyFilters(state);
-  return { filters };
-};
-export default connect(GraphComponentState)(GraphComponent);
+export default GraphComponent;
