@@ -56,12 +56,12 @@ const ObservedWorkloadNode: React.FC<WorkloadNodeProps> = ({
   const workloadData = element.getData().data;
   const filters = useDisplayFilters();
   const size = Math.min(width, height);
-  const { donutStatus, editURL, vcsURI } = workloadData;
+  const { donutStatus, editURL, vcsURI, vcsRef } = workloadData;
   const { radius, decoratorRadius } = calculateRadius(size);
   const cheEnabled = !!cheURL;
   const cx = width / 2;
   const cy = height / 2;
-  const editUrl = editURL || getEditURL(vcsURI, cheURL);
+  const editUrl = editURL || getEditURL(vcsURI, vcsRef, cheURL);
   const repoIcon = routeDecoratorIcon(editUrl, decoratorRadius, cheEnabled);
   const tipContent = `Create a ${
     serviceBinding && element.getData().operatorBackedService ? 'binding' : 'visual'
