@@ -1,53 +1,12 @@
-import { FirehoseResource } from '@console/internal/components/utils';
+import * as _ from 'lodash';
 import { K8sResourceKind, ImagePullPolicy } from '@console/internal/module/k8s';
-import {
-  getKnativeServiceDepResource,
-  knativeServingResourcesServices,
-  knativeServingResourcesRevision,
-  knativeServingResourcesConfigurations,
-  knativeServingResourcesRoutes,
-} from '../create-knative-utils';
+import { Resources } from '@console/dev-console/src/components/import/import-types';
+import { RequestType } from '@console/dev-console/src/components/health-checks/health-checks-types';
+import { healthChecksDefaultValues } from '@console/dev-console/src/components/health-checks/health-checks-probe-utils';
+import { getKnativeServiceDepResource } from '../create-knative-utils';
 import { defaultData } from './knative-serving-data';
 
 describe('Create knative Utils', () => {
-  describe('knative Serving Resources', () => {
-    const SAMPLE_NAMESPACE = 'mynamespace';
-    it('expect knativeServingResource to return service with proper namespace', () => {
-      const serviceServingResource: FirehoseResource[] = knativeServingResourcesServices(
-        SAMPLE_NAMESPACE,
-      );
-      expect(serviceServingResource).toHaveLength(1);
-      expect(serviceServingResource[0].namespace).toBe(SAMPLE_NAMESPACE);
-      expect(serviceServingResource[0].prop).toBe('ksservices');
-    });
-
-    it('expect knativeServingResourcesRevision to return revision with proper namespace', () => {
-      const revisionServingResource: FirehoseResource[] = knativeServingResourcesRevision(
-        SAMPLE_NAMESPACE,
-      );
-      expect(revisionServingResource).toHaveLength(1);
-      expect(revisionServingResource[0].namespace).toBe(SAMPLE_NAMESPACE);
-      expect(revisionServingResource[0].prop).toBe('revisions');
-    });
-
-    it('expect knativeServingResourcesConfigurations to return configurations with proper namespace', () => {
-      const configServingResource: FirehoseResource[] = knativeServingResourcesConfigurations(
-        SAMPLE_NAMESPACE,
-      );
-      expect(configServingResource).toHaveLength(1);
-      expect(configServingResource[0].namespace).toBe(SAMPLE_NAMESPACE);
-      expect(configServingResource[0].prop).toBe('configurations');
-    });
-
-    it('expect knativeServingResourcesRoutes to return routes with proper namespace', () => {
-      const routeServingResource: FirehoseResource[] = knativeServingResourcesRoutes(
-        SAMPLE_NAMESPACE,
-      );
-      expect(routeServingResource).toHaveLength(1);
-      expect(routeServingResource[0].namespace).toBe(SAMPLE_NAMESPACE);
-      expect(routeServingResource[0].prop).toBe('ksroutes');
-    });
-  });
   describe('knative Service creation', () => {
     it('expect knativeServingResourcesConfigurations to not have Ports id if unknownTargetPort is empty', () => {
       const knDeploymentResource: K8sResourceKind = getKnativeServiceDepResource(
@@ -168,5 +127,37 @@ describe('Create knative Utils', () => {
         ImagePullPolicy.IfNotPresent,
       );
     });
+
+    it('should have port value as 0 in the health checks probe data', () => {
+      const dataWithHealthChecksEnabled = _.cloneDeep(defaultData);
+      dataWithHealthChecksEnabled.resources = Resources.KnativeService;
+      dataWithHealthChecksEnabled.healthChecks.readinessProbe = {
+        ...healthChecksDefaultValues,
+        enabled: true,
+        data: {
+          ...healthChecksDefaultValues.data,
+          requestType: RequestType.HTTPGET,
+        },
+      };
+      dataWithHealthChecksEnabled.healthChecks.livenessProbe = {
+        ...healthChecksDefaultValues,
+        enabled: true,
+        data: {
+          ...healthChecksDefaultValues.data,
+          requestType: RequestType.TCPSocket,
+        },
+      };
+
+      const knDeploymentResource: K8sResourceKind = getKnativeServiceDepResource(
+        dataWithHealthChecksEnabled,
+        'imgStream',
+      );
+      expect(
+        knDeploymentResource.spec.template.spec.containers[0].readinessProbe.httpGet.port,
+      ).toBe(0);
+      expect(
+        knDeploymentResource.spec.template.spec.containers[0].livenessProbe.tcpSocket.port,
+      ).toBe(0);
+    });
   });
 });
