@@ -12,7 +12,6 @@ import {
 import {
   removeLeakedResources,
   waitForCount,
-  searchYAML,
   withResource,
   createResources,
   deleteResources,
@@ -22,7 +21,7 @@ import {
 } from '@console/shared/src/test-utils/utils';
 import * as cloneDialogView from '../views/dialogs/cloneVirtualMachineDialog.view';
 import { getVolumes, getDataVolumeTemplates } from '../../src/selectors/vm/selectors';
-import { getResourceObject, getRandStr, createProject } from './utils/utils';
+import { getRandStr, createProject } from './utils/utils';
 import {
   CLONE_VM_TIMEOUT_SECS,
   VM_BOOTUP_TIMEOUT_SECS,
@@ -44,6 +43,7 @@ import {
 } from './utils/mocks';
 import { VirtualMachine } from './models/virtualMachine';
 import { CloneVirtualMachineDialog } from './dialogs/cloneVirtualMachineDialog';
+import { Wizard } from './models/wizard';
 
 describe('Test clone VM.', () => {
   const leakedResources = new Set<string>();
@@ -76,7 +76,7 @@ describe('Test clone VM.', () => {
     });
 
     it(
-      'Displays warning in clone wizard when cloned vm is running.',
+      'ID(CNV-1730) Displays warning in clone wizard when cloned vm is running.',
       async () => {
         await vm.action(VM_ACTION.Start, false);
         await vm.waitForStatus(VM_STATUS.Starting, PAGE_LOAD_TIMEOUT_SECS);
@@ -99,7 +99,7 @@ describe('Test clone VM.', () => {
       VM_BOOTUP_TIMEOUT_SECS,
     );
 
-    it('Prefills correct data in the clone VM dialog.', async () => {
+    it('ID(CNV-1863) Prefills correct data in the clone VM dialog.', async () => {
       await vm.action(VM_ACTION.Clone);
       expect(cloneDialogView.nameInput.getAttribute('value')).toEqual(`${vm.name}-clone`);
       expect(cloneDialogView.descriptionInput.getText()).toEqual(
@@ -110,7 +110,7 @@ describe('Test clone VM.', () => {
       await cloneDialog.close();
     });
 
-    it('Validates VM name.', async () => {
+    it('ID(CNV-1732) Validates VM name.', async () => {
       await vm.action(VM_ACTION.Clone);
 
       expect(cloneDialogView.warningMessage.isPresent()).toBe(false);
@@ -179,7 +179,7 @@ describe('Test clone VM.', () => {
     });
 
     it(
-      'Clones VM to a different namespace',
+      'ID(CNV-3058) Clones VM to a different namespace',
       async () => {
         const vmClonedToOtherNS = new VirtualMachine({
           name: `${vm.name}-${getRandStr(4)}`,
@@ -197,7 +197,7 @@ describe('Test clone VM.', () => {
     );
 
     it(
-      'Start cloned VM on creation',
+      'ID(CNV-1733) Start cloned VM on creation',
       async () => {
         await vm.action(VM_ACTION.Clone);
         await cloneDialog.startOnCreation();
@@ -210,11 +210,11 @@ describe('Test clone VM.', () => {
       VM_BOOTUP_TIMEOUT_SECS + CLONE_VM_TIMEOUT_SECS,
     );
 
-    it('Running VM is stopped when cloned', async () => {
+    it('ID(CNV-2825) Running VM is stopped when cloned', async () => {
       await vm.waitForStatus(VM_STATUS.Off, PAGE_LOAD_TIMEOUT_SECS);
     });
 
-    it('Cloned VM has changed MAC address.', async () => {
+    it('ID(CNV-1734) Cloned VM has changed MAC address.', async () => {
       await clonedVM.navigateToTab(TAB.NetworkInterfaces);
       await browser.wait(until.and(waitForCount(resourceRows, 2)), PAGE_LOAD_TIMEOUT_SECS);
       const addedNIC = (await clonedVM.getAttachedNICs()).find(
@@ -223,10 +223,13 @@ describe('Test clone VM.', () => {
       expect(addedNIC.mac === multusNetworkInterface.mac).toBe(false);
     });
 
-    it('Cloned VM has vm.kubevirt.io/name label.', () => {
+    it('ID(CNV-1739) Cloned VM has vm.kubevirt.io/name label.', () => {
       expect(
-        searchYAML(`vm.kubevirt.io/name: ${vm.name}`, clonedVM.name, clonedVM.namespace, 'vm'),
-      ).toBeTruthy();
+        _.has(
+          _.get(clonedVM.getResource(), 'spec.template.metadata.labels'),
+          'vm.kubevirt.io/name',
+        ),
+      ).toBe(true);
     });
   });
 
@@ -239,7 +242,7 @@ describe('Test clone VM.', () => {
     };
 
     it(
-      'Test clone VM with URL source.',
+      'ID(CNV-1740) Test clone VM with URL source.',
       async () => {
         createResource(urlVMManifest);
         await withResource(leakedResources, urlVM.asResource(), async () => {
@@ -263,12 +266,7 @@ describe('Test clone VM.', () => {
             await resourceRowsPresent();
 
             // Verify cloned disk dataVolumeTemplate is present in cloned VM manifest
-            const clonedVMJSON = getResourceObject(
-              clonedVM.name,
-              clonedVM.namespace,
-              clonedVM.kind,
-            );
-            const clonedDataVolumeTemplate = getDataVolumeTemplates(clonedVMJSON);
+            const clonedDataVolumeTemplate = getDataVolumeTemplates(clonedVM.getResource());
             const result = _.find(
               clonedDataVolumeTemplate,
               (o) => o.metadata.name === clonedVMDiskName,
@@ -281,7 +279,7 @@ describe('Test clone VM.', () => {
     );
 
     it(
-      'Test clone VM with URL source and Cloud Init.',
+      'ID(CNV-1744) Test clone VM with URL source and Cloud Init.',
       async () => {
         const ciVMConfig = {
           name: `ci-${testName}`,
@@ -290,7 +288,7 @@ describe('Test clone VM.', () => {
           provisionSource: cloudInitVmProvisionConfig,
           storageResources: [rootDisk],
           networkResources: [],
-          flavor: basicVMConfig.flavor,
+          flavorConfig: basicVMConfig.flavorConfig,
           operatingSystem: basicVMConfig.operatingSystem,
           workloadProfile: basicVMConfig.workloadProfile,
           startOnCreation: false,
@@ -300,8 +298,9 @@ describe('Test clone VM.', () => {
           rootDisk,
           { name: 'cloudinitdisk', size: '', interface: 'VirtIO', storageClass: '-' },
         ];
-        const ciVM = new VirtualMachine(ciVMConfig);
-        await ciVM.create(ciVMConfig);
+
+        const wizard = new Wizard();
+        const ciVM = await wizard.createVirtualMachine(ciVMConfig);
         await withResource(leakedResources, ciVM.asResource(), async () => {
           await ciVM.action(VM_ACTION.Clone);
           await cloneDialog.clone();
@@ -317,12 +316,7 @@ describe('Test clone VM.', () => {
             });
 
             // Verify configuration of cloudinitdisk is the same
-            const clonedVMJSON = getResourceObject(
-              clonedVM.name,
-              clonedVM.namespace,
-              clonedVM.kind,
-            );
-            const clonedVMVolumes = getVolumes(clonedVMJSON);
+            const clonedVMVolumes = getVolumes(clonedVM.getResource());
             const result = _.find(clonedVMVolumes, (o) => o.name === 'cloudinitdisk');
             expect(result).toBeDefined();
             expect(_.get(result, 'cloudInitNoCloud.userData', '')).toEqual(
