@@ -14,11 +14,11 @@ import {
 import { MinusCircleIcon, PlusCircleIcon } from '@patternfly/react-icons';
 import { confirmModal } from '@console/internal/components/modals';
 import { joinGrammaticallyListOfItems } from '@console/shared/src';
-import { CloudInitField, VMWizardStorage, VMWizardStorageType } from '../../types';
+import { CloudInitField, VMWizardStorage, VMWizardStorageType, VMWizardTab } from '../../types';
 import { vmWizardActions } from '../../redux/actions';
 import { ActionType } from '../../redux/types';
 import { iGetCloudInitNoCloudStorage } from '../../selectors/immutable/storage';
-import { MutableVolumeWrapper, VolumeWrapper } from '../../../../k8s/wrapper/vm/volume-wrapper';
+import { VolumeWrapper } from '../../../../k8s/wrapper/vm/volume-wrapper';
 import { iGet, iGetIn, ihasIn, toJS, toShallowJS } from '../../../../utils/immutable';
 import { DiskBus, DiskType, VolumeType } from '../../../../constants/vm/storage';
 import { FormRow } from '../../../form/form-row';
@@ -33,7 +33,13 @@ import {
   CloudInitDataHelper,
   formAllowedKeys,
 } from '../../../../k8s/wrapper/vm/cloud-init-data-helper';
+import {
+  hasStepCreateDisabled,
+  hasStepDeleteDisabled,
+  hasStepUpdateDisabled,
+} from '../../selectors/immutable/wizard-selectors';
 
+import '../../create-vm-wizard-footer.scss';
 import './cloud-init-tab.scss';
 
 type CustomScriptProps = {
@@ -160,6 +166,7 @@ const CloudInitTabComponent: React.FC<ResultTabComponentProps> = ({
   setIsForm,
   updateStorage,
   removeStorage,
+  isDisabled,
 }) => {
   const asId = prefixedID.bind(null, 'cloudinit');
 
@@ -168,7 +175,8 @@ const CloudInitTabComponent: React.FC<ResultTabComponentProps> = ({
   );
 
   const isEditable =
-    !iCloudInitStorage || ihasIn(iCloudInitStorage, ['volume', 'cloudInitNoCloud']); // different type, e.g. networkData is not editable
+    !isDisabled &&
+    (!iCloudInitStorage || ihasIn(iCloudInitStorage, ['volume', 'cloudInitNoCloud'])); // different type, e.g. networkData is not editable
 
   const onDataChanged = (userData: string, encodeDataToBase64: boolean) => {
     if (
@@ -204,9 +212,9 @@ const CloudInitTabComponent: React.FC<ResultTabComponentProps> = ({
         id: iCloudInitStorage && iCloudInitStorage.get('id'),
         type: iCloudInitStorage && iCloudInitStorage.get('type'),
         disk: toShallowJS(iCloudInitStorage.get('disk')),
-        volume: new MutableVolumeWrapper(toJS(iCloudInitStorage.get('volume')))
-          .setTypeData(typeData, false)
-          .asMutableResource(),
+        volume: new VolumeWrapper(toJS(iCloudInitStorage.get('volume')))
+          .setTypeData(typeData)
+          .asResource(),
       });
     }
   };
@@ -267,8 +275,8 @@ const CloudInitTabComponent: React.FC<ResultTabComponentProps> = ({
     }
   };
   return (
-    <div>
-      {!isEditable && (
+    <div className={isForm && 'co-m-pane__body co-m-pane__form kubevirt-create-vm-modal__form'}>
+      {!isDisabled && !isEditable && (
         <Errors
           endMargin
           errors={[
@@ -327,6 +335,7 @@ const CloudInitTabComponent: React.FC<ResultTabComponentProps> = ({
 type ResultTabComponentProps = {
   wizardReduxID: string;
   iCloudInitStorage: any;
+  isDisabled: boolean;
   updateStorage: (storage: VMWizardStorage) => void;
   removeStorage: (storageId: string) => void;
   isForm: boolean;
@@ -338,6 +347,10 @@ const stateToProps = (state, { wizardReduxID }) => {
   return {
     iCloudInitStorage: iGetCloudInitNoCloudStorage(state, wizardReduxID),
     isForm,
+    isDisabled:
+      hasStepCreateDisabled(state, wizardReduxID, VMWizardTab.ADVANCED_CLOUD_INIT) ||
+      hasStepUpdateDisabled(state, wizardReduxID, VMWizardTab.ADVANCED_CLOUD_INIT) ||
+      hasStepDeleteDisabled(state, wizardReduxID, VMWizardTab.ADVANCED_CLOUD_INIT),
   };
 };
 
