@@ -12,57 +12,57 @@ import {
 } from '@patternfly/react-core';
 import { PlusCircleIcon } from '@patternfly/react-icons';
 import { Firehose, FirehoseResult } from '@console/internal/components/utils';
-import { K8sResourceKind } from '@console/internal/module/k8s';
 import { createLookup, getName } from '@console/shared/src';
 import { PersistentVolumeClaimModel } from '@console/internal/models';
-import { iGetCommonData, iGetCreateVMWizardTabs } from '../../selectors/immutable/selectors';
-import { isStepLocked } from '../../selectors/immutable/wizard-selectors';
-import { VMWizardProps, VMWizardStorageWithWrappers, VMWizardTab } from '../../types';
+import { iGetCommonData } from '../../selectors/immutable/selectors';
+import {
+  hasStepCreateDisabled,
+  hasStepDeleteDisabled,
+  hasStepUpdateDisabled,
+  isStepLocked,
+} from '../../selectors/immutable/wizard-selectors';
+import { VMWizardProps, VMWizardStorage, VMWizardTab } from '../../types';
 import { VMDisksTable } from '../../../vm-disks/vm-disks';
 import { vmWizardActions } from '../../redux/actions';
 import { ActionType } from '../../redux/types';
 import { iGetProvisionSource } from '../../selectors/immutable/vm-settings';
-import { getStoragesWithWrappers } from '../../selectors/selectors';
+import { getStorages } from '../../selectors/selectors';
 import { wrapWithProgress } from '../../../../utils/utils';
 import { diskTableColumnClasses } from '../../../vm-disks/utils';
 import { ProvisionSource } from '../../../../constants/vm/provision-source';
 import { CombinedDisk } from '../../../../k8s/wrapper/vm/combined-disk';
 import { isLoaded } from '../../../../utils';
 import { DeviceType } from '../../../../constants/vm';
-import { PersistentVolumeClaimWrapper } from '../../../../k8s/wrapper/vm/persistent-volume-claim-wrapper';
 import { VHW_TYPES } from '../virtual-hardware-tab/types';
 import { VmWizardStorageRow } from './vm-wizard-storage-row';
 import { VMWizardStorageBundle } from './types';
 import { vmWizardStorageModalEnhanced } from './vm-wizard-storage-modal-enhanced';
 import { StorageBootSource } from './storage-boot-source';
+import { ADD_DISK } from '../../../../utils/strings';
+import { DiskWrapper } from '../../../../k8s/wrapper/vm/disk-wrapper';
+import { VolumeWrapper } from '../../../../k8s/wrapper/vm/volume-wrapper';
 
 import './storage-tab.scss';
-import { ADD_DISK } from '../../../../utils/strings';
 
 const getStoragesData = (
-  storages: VMWizardStorageWithWrappers[],
-  pvcs: FirehoseResult<K8sResourceKind[]>,
+  storages: VMWizardStorage[],
+  pvcs: FirehoseResult,
 ): VMWizardStorageBundle[] => {
   const pvcLookup = createLookup(pvcs, getName);
 
   return storages
-    .filter((storage) => !VHW_TYPES.has(storage.diskWrapper.getType()))
+    .filter((storage) => !VHW_TYPES.has(new DiskWrapper(storage.disk).getType()))
     .map((wizardStorageData) => {
-      const {
-        diskWrapper,
-        volumeWrapper,
-        dataVolumeWrapper,
-        persistentVolumeClaimWrapper,
-      } = wizardStorageData;
-      const pvc = pvcLookup[volumeWrapper.getPersistentVolumeClaimName()];
+      const { disk, volume, dataVolume, persistentVolumeClaim } = wizardStorageData;
+
+      const pvc = pvcLookup[new VolumeWrapper(volume).getPersistentVolumeClaimName()];
 
       const combinedDisk = new CombinedDisk({
-        diskWrapper,
-        volumeWrapper,
-        dataVolumeWrapper,
-        persistentVolumeClaimWrapper:
-          persistentVolumeClaimWrapper || (pvc && PersistentVolumeClaimWrapper.initialize(pvc)),
-        isNewPVC: !!persistentVolumeClaimWrapper,
+        disk,
+        volume,
+        dataVolume,
+        persistentVolumeClaim: persistentVolumeClaim || pvc,
+        isNewPVC: !!persistentVolumeClaim,
         pvcsLoading: !isLoaded(pvcs),
       });
 
@@ -87,6 +87,9 @@ const StorageTabFirehose: React.FC<StorageTabFirehoseProps> = ({
   onBootOrderChanged,
   storages,
   persistentVolumeClaims,
+  isCreateDisabled,
+  isUpdateDisabled,
+  isDeleteDisabled,
 }) => {
   const showStorages = storages.length > 0 || isBootDiskRequired;
 
@@ -101,7 +104,7 @@ const StorageTabFirehose: React.FC<StorageTabFirehoseProps> = ({
           wizardReduxID,
         }).result,
       ),
-    isDisabled: isLocked,
+    isDisabled: isLocked || isCreateDisabled,
   };
 
   return (
@@ -123,10 +126,18 @@ const StorageTabFirehose: React.FC<StorageTabFirehoseProps> = ({
       {showStorages && (
         <>
           <VMDisksTable
-            columnClasses={diskTableColumnClasses}
             data={getStoragesData(storages, persistentVolumeClaims)}
-            customData={{ isDisabled: isLocked, withProgress, removeStorage, wizardReduxID }}
-            row={VmWizardStorageRow}
+            customData={{
+              isDisabled: isLocked,
+              withProgress,
+              removeStorage,
+              wizardReduxID,
+              isDeleteDisabled,
+              isUpdateDisabled,
+              columnClasses: diskTableColumnClasses,
+            }}
+            Row={VmWizardStorageRow}
+            loaded
           />
           {isBootDiskRequired && (
             <StorageBootSource
@@ -158,11 +169,14 @@ type StorageTabFirehoseProps = {
   isLocked: boolean;
   isBootDiskRequired: boolean;
   wizardReduxID: string;
-  storages: VMWizardStorageWithWrappers[];
+  storages: VMWizardStorage[];
   removeStorage: (id: string) => void;
+  isCreateDisabled: boolean;
+  isUpdateDisabled: boolean;
+  isDeleteDisabled: boolean;
   setTabLocked: (isLocked: boolean) => void;
   onBootOrderChanged: (deviceID: string, bootOrder: number) => void;
-  persistentVolumeClaims: FirehoseResult<K8sResourceKind[]>;
+  persistentVolumeClaims: FirehoseResult;
 };
 
 const StorageTabConnected: React.FC<StorageTabConnectedProps> = ({ namespace, ...rest }) => (
@@ -184,15 +198,15 @@ type StorageTabConnectedProps = StorageTabFirehoseProps & {
   namespace: string;
 };
 
-const stateToProps = (state, { wizardReduxID }) => {
-  const stepData = iGetCreateVMWizardTabs(state, wizardReduxID);
-  return {
-    namespace: iGetCommonData(state, wizardReduxID, VMWizardProps.activeNamespace),
-    isLocked: isStepLocked(stepData, VMWizardTab.STORAGE),
-    storages: getStoragesWithWrappers(state, wizardReduxID),
-    isBootDiskRequired: iGetProvisionSource(state, wizardReduxID) === ProvisionSource.DISK,
-  };
-};
+const stateToProps = (state, { wizardReduxID }) => ({
+  namespace: iGetCommonData(state, wizardReduxID, VMWizardProps.activeNamespace),
+  isLocked: isStepLocked(state, wizardReduxID, VMWizardTab.STORAGE),
+  isCreateDisabled: hasStepCreateDisabled(state, wizardReduxID, VMWizardTab.STORAGE),
+  isUpdateDisabled: hasStepUpdateDisabled(state, wizardReduxID, VMWizardTab.STORAGE),
+  isDeleteDisabled: hasStepDeleteDisabled(state, wizardReduxID, VMWizardTab.STORAGE),
+  storages: getStorages(state, wizardReduxID),
+  isBootDiskRequired: iGetProvisionSource(state, wizardReduxID) === ProvisionSource.DISK,
+});
 
 const dispatchToProps = (dispatch, { wizardReduxID }) => ({
   setTabLocked: (isLocked) => {
