@@ -5,13 +5,13 @@ import { toShallowJS } from '../../../../utils/immutable';
 import { FormFieldRow } from '../../form/form-field-row';
 import { FormField, FormFieldType } from '../../form/form-field';
 import { VMWizardStorage } from '../../types';
-import { MutableVolumeWrapper, VolumeWrapper } from '../../../../k8s/wrapper/vm/volume-wrapper';
+import { VolumeWrapper } from '../../../../k8s/wrapper/vm/volume-wrapper';
 import { VolumeType } from '../../../../constants/vm/storage';
 
 export const ContainerSource: React.FC<ContainerSourceProps> = React.memo(
   ({ field, provisionSourceStorage, onProvisionSourceStorageChange }) => {
     const storage: VMWizardStorage = toShallowJS(provisionSourceStorage);
-    const volumeWrapper = VolumeWrapper.initialize(storage?.volume);
+    const volumeWrapper = new VolumeWrapper(storage?.volume);
 
     return (
       <FormFieldRow
@@ -27,9 +27,9 @@ export const ContainerSource: React.FC<ContainerSourceProps> = React.memo(
             onChange={(image) =>
               onProvisionSourceStorageChange({
                 ...storage,
-                volume: new MutableVolumeWrapper(storage?.volume, true)
+                volume: new VolumeWrapper(storage?.volume, true)
                   .appendTypeData({ image }, false)
-                  .asMutableResource(),
+                  .asResource(),
               })
             }
           />
