@@ -13,10 +13,17 @@ import {
 } from '../../strings/strings';
 import { nullOnEmptyChange } from '../../utils/utils';
 import { iGetName } from '../../selectors/immutable/selectors';
-import { iGetFieldValue } from '../../selectors/immutable/vm-settings';
+import { iGetFieldValue } from '../../selectors/immutable/field';
 
 export const UserTemplates: React.FC<UserTemplatesProps> = React.memo(
-  ({ userTemplateField, userTemplates, commonTemplates, onChange, openshiftFlag }) => {
+  ({
+    userTemplateField,
+    forceSingleUserTemplateName,
+    userTemplates,
+    commonTemplates,
+    onChange,
+    openshiftFlag,
+  }) => {
     const data = iGetLoadedData(userTemplates);
     const names: string[] =
       data &&
@@ -28,6 +35,39 @@ export const UserTemplates: React.FC<UserTemplatesProps> = React.memo(
     const hasUserTemplates = sortedNames.length > 0;
     const hasFieldValue = typeof iGetFieldValue(userTemplateField) === 'undefined';
 
+    const optionUserTemplate = forceSingleUserTemplateName && (
+      <>
+        <FormSelectOption
+          key={forceSingleUserTemplateName}
+          value={forceSingleUserTemplateName}
+          label={forceSingleUserTemplateName}
+        />
+      </>
+    );
+
+    const optionNoTemplatesAvailable = !forceSingleUserTemplateName && !hasUserTemplates && (
+      <FormSelectOption
+        key={NO_TEMPLATE_AVAILABLE}
+        value=""
+        label={openshiftFlag ? NO_TEMPLATE_AVAILABLE : NO_OPENSHIFT_TEMPLATES}
+      />
+    );
+
+    const optionsList = !forceSingleUserTemplateName && hasUserTemplates && (
+      <>
+        <FormSelectOption
+          key={SELECT_TEMPLATE}
+          value=""
+          label={SELECT_TEMPLATE}
+          isDisabled={!hasFieldValue}
+        />
+        <FormSelectOption key={NO_TEMPLATE} value="" label={NO_TEMPLATE} />
+        {sortedNames.map((name) => (
+          <FormSelectOption key={name} value={name} label={name} />
+        ))}
+      </>
+    );
+
     return (
       <FormFieldRow
         field={userTemplateField}
@@ -43,27 +83,9 @@ export const UserTemplates: React.FC<UserTemplatesProps> = React.memo(
       >
         <FormField isDisabled={!hasUserTemplates}>
           <FormSelect onChange={nullOnEmptyChange(onChange, VMSettingsField.USER_TEMPLATE)}>
-            {hasUserTemplates && (
-              <>
-                <FormSelectOption
-                  key={SELECT_TEMPLATE}
-                  value=""
-                  label={SELECT_TEMPLATE}
-                  isDisabled={!hasFieldValue}
-                />
-                <FormSelectOption key={NO_TEMPLATE} value="" label={NO_TEMPLATE} />
-              </>
-            )}
-            {!hasUserTemplates && (
-              <FormSelectOption
-                key={NO_TEMPLATE_AVAILABLE}
-                value=""
-                label={openshiftFlag ? NO_TEMPLATE_AVAILABLE : NO_OPENSHIFT_TEMPLATES}
-              />
-            )}
-            {sortedNames.map((name) => (
-              <FormSelectOption key={name} value={name} label={name} />
-            ))}
+            {optionUserTemplate}
+            {optionNoTemplatesAvailable}
+            {optionsList}
           </FormSelect>
         </FormField>
       </FormFieldRow>
@@ -77,6 +99,7 @@ export const UserTemplates: React.FC<UserTemplatesProps> = React.memo(
 );
 
 type UserTemplatesProps = {
+  forceSingleUserTemplateName: string;
   userTemplateField: any;
   userTemplates: any;
   commonTemplates: any;
