@@ -5,7 +5,6 @@ import {
   Firehose,
   FirehoseResult,
   HandlePromiseProps,
-  validate,
   withHandlePromise,
 } from '@console/internal/components/utils';
 import { TemplateModel } from '@console/internal/models';
@@ -29,7 +28,7 @@ import { getUpdateFlavorPatches } from '../../../k8s/patches/vm/vm-patches';
 import { CUSTOM_FLAVOR } from '../../../constants';
 import { getLoadedData } from '../../../utils';
 import { SizeUnitFormRow } from '../../form/size-unit-form-row';
-import { BinaryUnit } from '../../form/size-unit-utils';
+import { BinaryUnit, stringValueUnitSplit } from '../../form/size-unit-utils';
 import { ModalFooter } from '../modal/modal-footer';
 import { FormRow } from '../../form/form-row';
 import { Integer } from '../../form/integer/integer';
@@ -40,13 +39,15 @@ import { getDialogUIError } from '../../../utils/strings';
 import { flavorSort } from '../../../utils/sort';
 import { getTemplateFlavors } from '../../../selectors/vm-template/advanced';
 import { getVMTemplateNamespacedName } from '../../../selectors/vm-template/selectors';
+import { toUIFlavor, isCustomFlavor } from '../../../selectors/vm-like/flavor';
 
 const getId = (field: string) => `vm-flavor-modal-${field}`;
 
-const getFlavors = (template: TemplateKind) => {
-  const flavors = [...getTemplateFlavors([template]), CUSTOM_FLAVOR];
+const getAvailableFlavors = (template: TemplateKind) => {
+  const flavors = getTemplateFlavors([template]).filter((f) => f && !isCustomFlavor(f));
+  flavors.push(CUSTOM_FLAVOR);
 
-  return _.uniq(flavorSort(flavors).filter((f) => f));
+  return _.uniq(flavorSort(flavors));
 };
 
 const VMFlavorModal = withHandlePromise((props: VMFlavornModalProps) => {
@@ -55,15 +56,15 @@ const VMFlavorModal = withHandlePromise((props: VMFlavornModalProps) => {
   const vm = asVM(vmLike);
   const underlyingTemplate = getLoadedData(template);
 
-  const flavors = getFlavors(underlyingTemplate);
-  const vmFlavor = getFlavor(vmLike) || flavors[flavors.length - 1];
+  const flavors = getAvailableFlavors(underlyingTemplate);
+  const vmFlavor = toUIFlavor(getFlavor(vmLike) || flavors[flavors.length - 1]);
 
-  const [sourceMemSize, sourceMemUnit] = validate.split(getMemory(vm) || '');
+  const [sourceMemSize, sourceMemUnit] = stringValueUnitSplit(getMemory(vm) || '');
   const sourceCPURaw = getCPU(vm);
   const sourceCPU = vCPUCount(sourceCPURaw);
 
   const [flavor, setFlavor] = React.useState(vmFlavor);
-  const isCustom = flavor === CUSTOM_FLAVOR;
+  const isCustom = isCustomFlavor(flavor);
 
   const [memSize, setMemSize] = React.useState<string>(isCustom ? sourceMemSize || '' : '');
   const [memUnit, setMemUnit] = React.useState<string>(
@@ -112,8 +113,8 @@ const VMFlavorModal = withHandlePromise((props: VMFlavornModalProps) => {
           <FormRow title="Flavor" fieldId={getId('flavor')} isRequired>
             <FormSelect
               onChange={(f) => {
-                if (f === CUSTOM_FLAVOR) {
-                  const isSourceCustom = vmFlavor === CUSTOM_FLAVOR;
+                if (isCustomFlavor(f)) {
+                  const isSourceCustom = isCustomFlavor(vmFlavor);
                   setMemSize(isSourceCustom ? sourceMemSize || '' : '');
                   setMemUnit(isSourceCustom ? sourceMemUnit || BinaryUnit.Gi : BinaryUnit.Gi);
                   setCpus(isSourceCustom ? `${sourceCPU}` : '');
