@@ -1,12 +1,16 @@
-import { ConfigMapKind, TemplateKind } from '@console/internal/module/k8s';
+import { TemplateKind } from '@console/internal/module/k8s';
 import { Map as ImmutableMap } from 'immutable';
 import { EnhancedK8sMethods } from '../../../enhancedK8sMethods/enhancedK8sMethods';
-import { VMSettings } from '../../../../components/create-vm-wizard/redux/initial-state/types';
+import {
+  ImportProvidersSettings,
+  VMSettings,
+} from '../../../../components/create-vm-wizard/redux/initial-state/types';
 import { VMWizardNetwork, VMWizardStorage } from '../../../../components/create-vm-wizard/types';
 import { ITemplate } from '../../../../types/template';
 
 export type CreateVMParams = {
   enhancedK8sMethods: EnhancedK8sMethods;
+  importProviders: ImportProvidersSettings;
   vmSettings: VMSettings;
   networks: VMWizardNetwork[];
   storages: VMWizardStorage[];
@@ -14,14 +18,11 @@ export type CreateVMParams = {
   iCommonTemplates: ImmutableMap<string, ITemplate>;
   namespace: string;
   openshiftFlag: boolean;
-};
-
-export type CreateVMEnhancedParams = CreateVMParams & {
-  storageClassConfigMap: ConfigMapKind;
+  isProviderImport: boolean;
   isTemplate: boolean;
 };
 
-export type DefaultTemplateParams = {
+export type DefaultVMLikeEntityParams = {
   commonTemplate: TemplateKind;
   namespace: string;
   name: string;
