@@ -1,6 +1,5 @@
 import * as React from 'react';
 import * as _ from 'lodash';
-import * as virtualMachineIcon from './images/virtual-machine.svg';
 import {
   Plugin,
   ResourceNSNavItem,
@@ -21,7 +20,6 @@ import {
 import { DashboardsStorageCapacityDropdownItem } from '@console/ceph-storage-plugin';
 import { TemplateModel, PodModel } from '@console/internal/models';
 import { getName } from '@console/shared/src/selectors/common';
-import { AddAction } from '@console/dev-console/src/extensions/add-actions';
 import { FirehoseResource } from '@console/internal/components/utils';
 import * as models from './models';
 import { VMTemplateYAMLTemplates, VirtualMachineYAMLTemplates } from './models/templates';
@@ -31,7 +29,6 @@ import {
   VMOffGroupIcon,
 } from './components/dashboards-page/overview-dashboard/inventory';
 import kubevirtReducer from './redux';
-import { accessReviewImportVM } from './utils/accessReview-v2v';
 import { diskImportKindMapping } from './components/dashboards-page/overview-dashboard/utils';
 
 import './style.scss';
@@ -51,8 +48,7 @@ type ConsumedExtensions =
   | DashboardsStorageCapacityDropdownItem
   | ReduxReducer
   | ProjectDashboardInventoryItem
-  | DashboardsOverviewResourceActivity
-  | AddAction;
+  | DashboardsOverviewResourceActivity;
 
 export const FLAG_KUBEVIRT = 'KUBEVIRT';
 
@@ -412,20 +408,6 @@ const plugin: Plugin<ConsumedExtensions> = [
       required: [FLAG_KUBEVIRT],
     },
   },
-  {
-    type: 'AddAction',
-    flags: {
-      required: [FLAG_KUBEVIRT],
-    },
-    properties: {
-      id: 'import-via-v2v',
-      url: '/k8s/ns/:namespace/virtualization/~new-wizard?mode=import',
-      label: 'Import Virtual Machine',
-      description: 'Import a virtual machine from external hypervisor',
-      icon: virtualMachineIcon,
-      accessReview: accessReviewImportVM,
-    },
-  },
 ];
 
 export default plugin;
