@@ -15,8 +15,8 @@ import { StorageUISource } from '../../../components/modals/disk-modal/storage-u
 import { CombinedDisk } from '../../../k8s/wrapper/vm/combined-disk';
 import { PersistentVolumeClaimWrapper } from '../../../k8s/wrapper/vm/persistent-volume-claim-wrapper';
 import { DiskType } from '../../../constants/vm/storage/disk-type';
-import { UIDiskValidation } from './types';
 import { TemplateValidations } from '../template/template-validations';
+import { UIStorageValidation } from '../../../types/ui/storage';
 
 const validateDiskName = (name: string, usedDiskNames: Set<string>): ValidationObject => {
   let validation = validateDNS1123SubdomainValue(name);
@@ -60,7 +60,7 @@ export const validateDisk = (
     usedPVCNames?: Set<string>;
     templateValidations: TemplateValidations;
   },
-): UIDiskValidation => {
+): UIStorageValidation => {
   const validations = {
     name: validateDiskName(disk && disk.getName(), usedDiskNames),
     size: null,
@@ -69,7 +69,7 @@ export const validateDisk = (
     diskInterface: null,
     pvc: null,
   };
-  let hasAllRequiredFilled = disk && disk.getName();
+  let hasAllRequiredFilled = disk && disk.getName() && volume && volume.getName();
 
   const addRequired = (addon) => {
     if (hasAllRequiredFilled) {
@@ -86,7 +86,7 @@ export const validateDisk = (
   const tValidations = templateValidations || new TemplateValidations();
   const diskType = disk.getType();
 
-  if (source.requiresVolume()) {
+  if (source.requiresVolumeType()) {
     addRequired(volume && volume.hasType());
   }
 
@@ -133,7 +133,7 @@ export const validateDisk = (
       dataVolumeWrapper: dataVolume,
       persistentVolumeClaimWrapper,
       isNewPVC: !!persistentVolumeClaimWrapper,
-    }).getPVCName(source);
+    }).getPVCNameBySource(source);
     addRequired(pvcName);
     validations.pvc = validatePVCName(pvcName, usedPVCNames);
   }
