@@ -3,8 +3,15 @@ import * as classNames from 'classnames';
 import { Kebab, ResourceLink } from '@console/internal/components/utils';
 import { sortable } from '@patternfly/react-table';
 import { getName, getUID, getNamespace, DASH } from '@console/shared';
-import { TableRow, TableData, Table } from '@console/internal/components/factory';
+import {
+  TableRow,
+  TableData,
+  Table,
+  RowFunction,
+  RowFunctionArgs,
+} from '@console/internal/components/factory';
 import { referenceForModel } from '@console/internal/module/k8s';
+import { useFlag } from '@console/shared/src/hooks/flag';
 import { BareMetalHostBundle } from '../types';
 import { getHostBMCAddress, getHostVendorInfo } from '../../selectors';
 import { BareMetalHostModel } from '../../models';
@@ -13,6 +20,7 @@ import BareMetalHostStatus from './BareMetalHostStatus';
 import BareMetalHostRole from './BareMetalHostRole';
 import { menuActions } from './host-menu-actions';
 import BareMetalHostSecondaryStatus from './BareMetalHostSecondaryStatus';
+import { NODE_MAINTENANCE_FLAG } from '../../features';
 
 const tableColumnClasses = {
   name: classNames('col-lg-2', 'col-md-4', 'col-sm-12', 'col-xs-12'),
@@ -67,23 +75,13 @@ const HostsTableHeader = () => [
   },
 ];
 
-type HostsTableRowProps = {
-  obj: BareMetalHostBundle;
-  customData: {
-    hasNodeMaintenanceCapability: boolean;
-  };
-  index: number;
-  key?: string;
-  style: React.StyleHTMLAttributes<any>;
-};
-
-const HostsTableRow: React.FC<HostsTableRowProps> = ({
+const HostsTableRow: React.FC<RowFunctionArgs<BareMetalHostBundle>> = ({
   obj: { host, node, nodeMaintenance, machine, machineSet, status },
-  customData: { hasNodeMaintenanceCapability },
   index,
   key,
   style,
 }) => {
+  const hasNodeMaintenanceCapability = useFlag(NODE_MAINTENANCE_FLAG);
   const name = getName(host);
   const namespace = getNamespace(host);
   const address = getHostBMCAddress(host);
@@ -101,7 +99,7 @@ const HostsTableRow: React.FC<HostsTableRowProps> = ({
         />
       </TableData>
       <TableData className={tableColumnClasses.status}>
-        <BareMetalHostStatus {...status} />
+        <BareMetalHostStatus {...status} nodeMaintenance={nodeMaintenance} host={host} />
         <BareMetalHostSecondaryStatus host={host} />
       </TableData>
       <TableData className={tableColumnClasses.node}>
@@ -121,7 +119,7 @@ const HostsTableRow: React.FC<HostsTableRowProps> = ({
               hasNodeMaintenanceCapability,
               machine,
               machineSet,
-              status: status.status,
+              status,
             }),
           )}
           key={`kebab-for-${uid}`}
@@ -134,20 +132,23 @@ const HostsTableRow: React.FC<HostsTableRowProps> = ({
 
 type BareMetalHostsTableProps = React.ComponentProps<typeof Table> & {
   data: BareMetalHostBundle[];
-  customData: {
-    hasNodeMaintenanceCapability: boolean;
-  };
 };
 
-const BareMetalHostsTable: React.FC<BareMetalHostsTableProps> = (props) => (
-  <Table
-    {...props}
-    defaultSortField="host.metadata.name"
-    aria-label="Bare Metal Hosts"
-    Header={HostsTableHeader}
-    Row={HostsTableRow}
-    virtualize
-  />
-);
+const BareMetalHostsTable: React.FC<BareMetalHostsTableProps> = (props) => {
+  const row = React.useCallback<RowFunction<BareMetalHostBundle>>(
+    (rowProps) => <HostsTableRow {...rowProps} />,
+    [],
+  );
+  return (
+    <Table
+      {...props}
+      defaultSortField="host.metadata.name"
+      aria-label="Bare Metal Hosts"
+      Header={HostsTableHeader}
+      Row={row}
+      virtualize
+    />
+  );
+};
 
 export default BareMetalHostsTable;
