@@ -1,5 +1,5 @@
 import * as _ from 'lodash';
-import { getName } from '@console/shared/src/selectors/common';
+import { getName, getAnnotations } from '@console/shared/src/selectors/common';
 import { MachineKind } from '@console/internal/module/k8s';
 import {
   BareMetalHostDisk,
@@ -16,6 +16,8 @@ import {
   HOST_POWER_STATUS_POWERED_OFF,
 } from '../constants';
 
+const ANNOTATION_HOST_RESTART = 'reboot.metal3.io';
+
 export const getHostOperationalStatus = (host: BareMetalHostKind): string =>
   _.get(host, 'status.operationalStatus');
 export const getHostErrorType = (host: BareMetalHostKind): string => host.status?.errorType;
@@ -25,6 +27,8 @@ export const getHostMachineName = (host: BareMetalHostKind): string =>
   _.get(host, 'spec.consumerRef.name');
 export const getHostBMCAddress = (host: BareMetalHostKind): string =>
   _.get(host, 'spec.bmc.address');
+export const getHostDisableCertificateVerification = (host: BareMetalHostKind): boolean =>
+  _.get(host, 'spec.bmc.disableCertificateVerification', false);
 export const getHostBootMACAddress = (host: BareMetalHostKind) =>
   _.get(host, 'spec') && host.spec.bootMACAddress;
 export const isHostOnline = (host: BareMetalHostKind): boolean => _.get(host, 'spec.online', false);
@@ -42,6 +46,12 @@ export const getHostDescription = (host: BareMetalHostKind): string =>
   _.get(host, 'spec.description', '');
 export const isHostPoweredOn = (host: BareMetalHostKind): boolean =>
   _.get(host, 'status.poweredOn', false);
+export const isHostScheduledForRestart = (host: BareMetalHostKind) =>
+  !!Object.getOwnPropertyNames(getAnnotations(host, {})).find(
+    (annotation) =>
+      annotation === ANNOTATION_HOST_RESTART ||
+      annotation.startsWith(`${ANNOTATION_HOST_RESTART}/`),
+  );
 export const getHostPowerStatus = (host: BareMetalHostKind): string => {
   const isOnline = isHostOnline(host);
   const isPoweredOn = isHostPoweredOn(host);
