@@ -8,14 +8,14 @@ import { getNodeMaintenanceStatus } from './node-maintenance-status';
 
 type BareMetalNodeStatusProps = {
   node: NodeKind;
-  nodeMaintenance: K8sResourceKind;
+  nodeMaintenance?: K8sResourceKind;
 };
 
 export const bareMetalNodeStatus = ({
   node,
   nodeMaintenance,
 }: BareMetalNodeStatusProps): StatusProps =>
-  getNodeMaintenanceStatus(nodeMaintenance) || { status: nodeStatus(node), node };
+  getNodeMaintenanceStatus(nodeMaintenance) || { status: nodeStatus(node) };
 
 type BareMetalNodeSecondaryStatusProps = {
   node: NodeKind;
@@ -33,6 +33,8 @@ export const baremetalNodeSecondaryStatus = ({
     states.push('Scheduling disabled');
   }
   // show host power status only if there is actual host associated to node
-  if (host && !isHostPoweredOn(host)) states.push('Host is powered off');
+  if (host && !isHostPoweredOn(host)) {
+    states.push('Host is powered off');
+  }
   return states;
 };
