@@ -1,17 +1,15 @@
 import * as React from 'react';
 import * as _ from 'lodash';
 import { Gallery, GalleryItem } from '@patternfly/react-core';
-import { ALERTS_KEY } from '@console/internal/actions/dashboards';
 import AlertsBody from '@console/shared/src/components/dashboard/status-card/AlertsBody';
 import AlertItem from '@console/shared/src/components/dashboard/status-card/AlertItem';
-import { alertURL, PrometheusRulesResponse } from '@console/internal/components/monitoring';
+import { alertURL } from '@console/internal/components/monitoring';
 import DashboardCard from '@console/shared/src/components/dashboard/dashboard-card/DashboardCard';
 import DashboardCardBody from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardBody';
 import DashboardCardHeader from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardHeader';
 import DashboardCardTitle from '@console/shared/src/components/dashboard/dashboard-card/DashboardCardTitle';
 import HealthBody from '@console/shared/src/components/dashboard/status-card/HealthBody';
 import HealthItem from '@console/shared/src/components/dashboard/status-card/HealthItem';
-import { getAlerts } from '@console/shared/src/components/dashboard/status-card/alert-utils';
 import { PrometheusResponse } from '@console/internal/components/graphs';
 import {
   withDashboardResources,
@@ -34,29 +32,27 @@ const noobaaResource: FirehoseResource = {
   prop: 'noobaa',
 };
 
-const NooBaaAlerts = withDashboardResources(({ watchAlerts, stopWatchAlerts, alertsResults }) => {
-  React.useEffect(() => {
-    watchAlerts();
-    return () => {
-      stopWatchAlerts();
-    };
-  }, [watchAlerts, stopWatchAlerts]);
+const NooBaaAlerts = withDashboardResources(
+  ({ watchAlerts, stopWatchAlerts, notificationAlerts }) => {
+    React.useEffect(() => {
+      watchAlerts();
+      return () => {
+        stopWatchAlerts();
+      };
+    }, [watchAlerts, stopWatchAlerts]);
 
-  const alertsResponse = alertsResults.getIn([ALERTS_KEY, 'data']) as PrometheusRulesResponse;
-  const alertsResponseError = alertsResults.getIn([ALERTS_KEY, 'loadError']);
-  const alerts = filterNooBaaAlerts(getAlerts(alertsResponse));
+    const { data, loaded, loadError } = notificationAlerts || {};
+    const alerts = filterNooBaaAlerts(data);
 
-  return (
-    <AlertsBody
-      isLoading={!alertsResponse}
-      error={alertsResponseError}
-      emptyMessage="No object service alerts"
-    >
-      {alerts.length > 0 &&
-        alerts.map((alert) => <AlertItem key={alertURL(alert, alert.rule.id)} alert={alert} />)}
-    </AlertsBody>
-  );
-});
+    return (
+      <AlertsBody error={!_.isEmpty(loadError)}>
+        {loaded &&
+          alerts.length > 0 &&
+          alerts.map((alert) => <AlertItem key={alertURL(alert, alert.rule.id)} alert={alert} />)}
+      </AlertsBody>
+    );
+  },
+);
 
 const StatusCard: React.FC<DashboardItemProps> = ({
   watchK8sResource,
@@ -123,10 +119,9 @@ const StatusCard: React.FC<DashboardItemProps> = ({
     noobaa,
   );
 
-  const dataResiliencyState: ObjectServiceState = getDataResiliencyState(
-    [progressResult],
-    [progressError],
-  );
+  const dataResiliencyState: ObjectServiceState = getDataResiliencyState([
+    { response: progressResult, error: progressError },
+  ]);
 
   return (
     <DashboardCard gradient>
@@ -144,7 +139,11 @@ const StatusCard: React.FC<DashboardItemProps> = ({
               />
             </GalleryItem>
             <GalleryItem>
-              <HealthItem title="Data Resiliency" state={dataResiliencyState.state} />
+              <HealthItem
+                title="Data Resiliency"
+                state={dataResiliencyState.state}
+                details={dataResiliencyState.message}
+              />
             </GalleryItem>
           </Gallery>
         </HealthBody>
