@@ -10,7 +10,13 @@ import {
   MsgBox,
   FirehoseResource,
 } from '@console/internal/components/utils';
-import { MultiListPage, Table, TableRow, TableData } from '@console/internal/components/factory';
+import {
+  MultiListPage,
+  Table,
+  TableRow,
+  TableData,
+  RowFunction,
+} from '@console/internal/components/factory';
 import {
   K8sResourceKind,
   GroupVersionKind,
@@ -19,7 +25,8 @@ import {
   referenceForGroupVersionKind,
 } from '@console/internal/module/k8s';
 import { CRDDescription, ClusterServiceVersionKind } from '../types';
-import { referenceForProvidedAPI, providedAPIsFor, OperandLink } from './index';
+import { referenceForProvidedAPI, providedAPIsFor } from './index';
+import { OperandLink } from './operand/operand-link';
 
 const tableColumnClasses = [
   classNames('col-lg-4', 'col-md-4', 'col-sm-4', 'col-xs-6'),
@@ -55,12 +62,12 @@ export const ResourceTableHeader = () => [
   },
 ];
 
-export const ResourceTableRow: React.FC<ResourceTableRowProps> = ({
-  obj,
-  index,
-  style,
-  customData: { linkFor },
-}) => (
+export const ResourceTableRow: RowFunction<
+  K8sResourceKind,
+  {
+    linkFor: (obj: K8sResourceKind) => JSX.Element;
+  }
+> = ({ obj, index, style, customData: { linkFor } }) => (
   <TableRow id={obj.metadata.uid} index={index} trKey={obj.metadata.uid} style={style}>
     <TableData className={tableColumnClasses[0]}>{linkFor(obj)}</TableData>
     <TableData className={tableColumnClasses[1]}>{obj.kind}</TableData>
@@ -152,7 +159,7 @@ export const Resources: React.FC<ResourcesProps> = (props) => {
       rowFilters={[
         {
           type: 'clusterserviceversion-resource-kind',
-          selected: firehoseResources.map(({ kind }) => kindForReference(kind)),
+          filterGroupName: 'Kind',
           reducer: ({ kind }) => kindForReference(kind),
           items: firehoseResources.map(({ kind }) => ({
             id: kindForReference(kind),
@@ -174,16 +181,6 @@ export type ResourcesProps = {
   match: match<{ plural: GroupVersionKind; ns: string; appName: string; name: string }>;
 };
 
-export type ResourceTableRowProps = {
-  obj: K8sResourceKind;
-  index: number;
-  key?: string;
-  style: object;
-  customData: {
-    linkFor: (obj: K8sResourceKind) => JSX.Element;
-  };
-};
-
 export type ResourceListProps = {};
 
 export type ResourceTableProps = {
