@@ -4,19 +4,27 @@ import { observer } from 'mobx-react';
 import ElementContext from '../utils/ElementContext';
 import { EventListener, isNode, Node } from '../types';
 import { useDndDrag, WithDndDragProps, Modifiers } from './useDndDrag';
-import { DragSourceSpec, DragEvent, ConnectDragSource, DragObjectWithType } from './dnd-types';
+import {
+  DragSourceSpec,
+  DragEvent,
+  ConnectDragSource,
+  DragObjectWithType,
+  DragSpecOperationType,
+  DragOperationWithType,
+  DragSourceMonitor,
+} from './dnd-types';
 import { useDndManager } from './useDndManager';
 
 export const DRAG_NODE_EVENT = 'drag_node';
 export const DRAG_NODE_START_EVENT = `${DRAG_NODE_EVENT}_start`;
 export const DRAG_NODE_END_EVENT = `${DRAG_NODE_EVENT}_end`;
 
-export type DragNodeEventListener = EventListener<[Node, DragEvent, string]>;
+export type DragNodeEventListener = EventListener<[Node, DragEvent, DragOperationWithType]>;
 
 export const DRAG_MOVE_OPERATION = 'move.useDragNode';
 
 const defaultOperation = {
-  [Modifiers.DEFAULT]: DRAG_MOVE_OPERATION,
+  [Modifiers.DEFAULT]: { type: DRAG_MOVE_OPERATION },
 };
 
 export const useDragNode = <
@@ -25,7 +33,16 @@ export const useDragNode = <
   CollectedProps extends {} = {},
   Props extends {} = {}
 >(
-  spec?: Omit<DragSourceSpec<DragObject, DropResult, CollectedProps, Props>, 'item'> & {
+  spec?: Omit<
+    DragSourceSpec<
+      DragObject,
+      DragSpecOperationType<DragOperationWithType>,
+      DropResult,
+      CollectedProps,
+      Props
+    >,
+    'item'
+  > & {
     item?: DragObject;
   },
   props?: Props,
@@ -41,9 +58,9 @@ export const useDragNode = <
 
   return useDndDrag(
     React.useMemo(() => {
-      const sourceSpec: DragSourceSpec<any, any, any, Props> = {
+      const sourceSpec: DragSourceSpec<any, any, any, any, Props> = {
         item: (spec && spec.item) || { type: '#useDragNode#' },
-        operation: (monitor, p) => {
+        operation: (monitor: DragSourceMonitor, p: Props) => {
           if (spec) {
             const operation =
               typeof spec.operation === 'function' ? spec.operation(monitor, p) : spec.operation;
@@ -90,9 +107,9 @@ export const useDragNode = <
               }
             }
             if (moved) {
-              e.setBounds(
+              e.setPosition(
                 e
-                  .getBounds()
+                  .getPosition()
                   .clone()
                   .translate(dx, dy),
               );
@@ -147,7 +164,16 @@ export const withDragNode = <
   CollectedProps extends {} = {},
   Props extends {} = {}
 >(
-  spec?: Omit<DragSourceSpec<DragObject, DropResult, CollectedProps, Props>, 'item'> & {
+  spec?: Omit<
+    DragSourceSpec<
+      DragObject,
+      DragSpecOperationType<DragOperationWithType>,
+      DropResult,
+      CollectedProps,
+      Props
+    >,
+    'item'
+  > & {
     item?: DragObject;
   },
 ) => <P extends WithDragNodeProps & CollectedProps & Props>(
