@@ -12,6 +12,9 @@ import {
   NODE_COLLAPSE_CHANGE_EVENT,
   NodeCollapseChangeEventListener,
   NodeStyle,
+  ElementVisibilityChangeEventListener,
+  ELEMENT_VISIBILITY_CHANGE_EVENT,
+  ElementVisibilityChangeEvent,
 } from '../types';
 import {
   leafNodeElements,
@@ -24,6 +27,7 @@ import {
   DRAG_NODE_START_EVENT,
   DragEvent,
   DragNodeEventListener,
+  DragOperationWithType,
 } from '../behavior';
 import { BaseEdge } from '../elements';
 import { ForceSimulation } from './ForceSimulation';
@@ -283,19 +287,19 @@ class BaseLayout implements Layout {
   }
 
   // eslint-disable-next-line @typescript-eslint/no-unused-vars
-  protected initDrag(element: Node, event: DragEvent, operation: string): void {}
+  protected initDrag(element: Node, event: DragEvent, operation: DragOperationWithType): void {}
 
   // eslint-disable-next-line @typescript-eslint/no-unused-vars
-  protected endDrag(element: Node, event: DragEvent, operation: string): void {}
+  protected endDrag(element: Node, event: DragEvent, operation: DragOperationWithType): void {}
 
-  handleDragStart = (element: Node, event: DragEvent, operation: string) => {
+  handleDragStart = (element: Node, event: DragEvent, operation: DragOperationWithType) => {
     this.initDrag(element, event, operation);
 
     if (!this.options.layoutOnDrag) {
       return;
     }
 
-    if (operation !== DRAG_MOVE_OPERATION) {
+    if (operation.type !== DRAG_MOVE_OPERATION) {
       this.forceSimulation.stopSimulation();
       return;
     }
@@ -326,14 +330,14 @@ class BaseLayout implements Layout {
     }
   };
 
-  handleDragEnd = (element: Node, event: DragEvent, operation: string) => {
+  handleDragEnd = (element: Node, event: DragEvent, operation: DragOperationWithType) => {
     this.endDrag(element, event, operation);
 
     if (!this.options.layoutOnDrag) {
       return;
     }
 
-    if (operation !== DRAG_MOVE_OPERATION) {
+    if (operation.type !== DRAG_MOVE_OPERATION) {
       this.forceSimulation.restart();
       return;
     }
@@ -365,36 +369,57 @@ class BaseLayout implements Layout {
   };
 
   private startListening(): void {
-    this.graph.getController().addEventListener(ADD_CHILD_EVENT, this.handleChildAdded);
-    this.graph.getController().addEventListener(REMOVE_CHILD_EVENT, this.handleChildRemoved);
-    this.graph
-      .getController()
-      .addEventListener(NODE_COLLAPSE_CHANGE_EVENT, this.handleNodeCollapse);
+    const controller = this.graph.getController();
+    if (controller) {
+      controller.addEventListener(ADD_CHILD_EVENT, this.handleChildAdded);
+      controller.addEventListener(REMOVE_CHILD_EVENT, this.handleChildRemoved);
+      controller.addEventListener(
+        ELEMENT_VISIBILITY_CHANGE_EVENT,
+        this.handleElementVisibilityChange,
+      );
+      controller.addEventListener(NODE_COLLAPSE_CHANGE_EVENT, this.handleNodeCollapse);
+    }
   }
 
   private stopListening(): void {
-    clearTimeout(this.scheduleHandle);
-    this.graph.getController().removeEventListener(ADD_CHILD_EVENT, this.handleChildAdded);
-    this.graph.getController().removeEventListener(REMOVE_CHILD_EVENT, this.handleChildRemoved);
-    this.graph
-      .getController()
-      .removeEventListener(NODE_COLLAPSE_CHANGE_EVENT, this.handleNodeCollapse);
+    const controller = this.graph.getController();
+    if (this.scheduleHandle) {
+      window.cancelAnimationFrame(this.scheduleHandle);
+    }
+    if (controller) {
+      controller.removeEventListener(ADD_CHILD_EVENT, this.handleChildAdded);
+      controller.removeEventListener(REMOVE_CHILD_EVENT, this.handleChildRemoved);
+      controller.removeEventListener(
+        ELEMENT_VISIBILITY_CHANGE_EVENT,
+        this.handleElementVisibilityChange,
+      );
+      controller.removeEventListener(NODE_COLLAPSE_CHANGE_EVENT, this.handleNodeCollapse);
+    }
   }
 
-  private handleChildAdded: ElementChildEventListener = ({ child }): void => {
+  protected handleChildAdded: ElementChildEventListener = ({ child }): void => {
     if (!this.nodesMap[child.getId()]) {
       this.scheduleRestart = true;
       this.scheduleLayout();
     }
   };
 
-  private handleChildRemoved: ElementChildEventListener = ({ child }): void => {
+  protected handleChildRemoved: ElementChildEventListener = ({ child }): void => {
     if (this.nodesMap[child.getId()]) {
       this.scheduleRestart = true;
       this.scheduleLayout();
     }
   };
 
+  protected handleElementVisibilityChange: ElementVisibilityChangeEventListener = (
+    event: ElementVisibilityChangeEvent,
+  ): void => {
+    if (event.visible === (this.nodesMap[event.target.getId()] === undefined)) {
+      this.scheduleRestart = true;
+      this.scheduleLayout();
+    }
+  };
+
   private handleNodeCollapse: NodeCollapseChangeEventListener = ({ node }): void => {
     if (!node.isCollapsed()) {
       this.scheduleRestart = true;
@@ -404,11 +429,11 @@ class BaseLayout implements Layout {
 
   private scheduleLayout = (): void => {
     if (!this.scheduleHandle) {
-      this.scheduleHandle = window.setTimeout(() => {
+      this.scheduleHandle = window.requestAnimationFrame(() => {
         delete this.scheduleHandle;
         this.runLayout(false, this.scheduleRestart);
         this.scheduleRestart = false;
-      }, 0);
+      });
     }
   };
 
@@ -423,15 +448,15 @@ class BaseLayout implements Layout {
       return undefined;
     }
 
-    let colaNode = _.find(nodes, { id: node.getId() });
-    if (!colaNode && _.size(node.getChildren())) {
-      colaNode = _.find(nodes, { id: node.getChildren()[0].getId() });
+    let layoutNode = _.find(nodes, { id: node.getId() });
+    if (!layoutNode && _.size(node.getChildren())) {
+      layoutNode = _.find(nodes, { id: node.getChildren()[0].getId() });
     }
-    if (!colaNode) {
-      colaNode = this.getLayoutNode(nodes, getClosestVisibleParent(node));
+    if (!layoutNode) {
+      layoutNode = this.getLayoutNode(nodes, getClosestVisibleParent(node));
     }
 
-    return colaNode;
+    return layoutNode;
   }
 
   protected getFauxEdges(groups: LayoutGroup[], nodes: LayoutNode[]): LayoutLink[] {
@@ -507,7 +532,7 @@ class BaseLayout implements Layout {
     let count = 0;
     const groupNodes: LayoutNode[] = [];
     groups.forEach((group: Node) => {
-      if (group.getChildren().length === 0) {
+      if (group.getChildren().filter((c) => c.isVisible()).length === 0) {
         groupNodes.push(this.createLayoutNode(group, nodeDistance, nodeCount + count++));
       }
     });
@@ -519,7 +544,7 @@ class BaseLayout implements Layout {
     let nodeIndex = nodes.length;
     // Create groups only for those with children
     const layoutGroups: LayoutGroup[] = groups
-      .filter((g) => g.getChildren().length > 0)
+      .filter((g) => g.getChildren().filter((c) => c.isVisible()).length > 0)
       .map((group: Node) => this.createLayoutGroup(group, padding, nodeIndex++));
 
     layoutGroups.forEach((groupNode: LayoutGroup) => {
@@ -540,10 +565,10 @@ class BaseLayout implements Layout {
         .getChildren()
         .filter((node: Node) => node.isGroup() && !node.isCollapsed());
       groupElements.forEach((group: Node) => {
-        const colaGroup = layoutGroups.find((g) => g.id === group.getId());
-        if (colaGroup) {
-          childGroups.push(colaGroup);
-          colaGroup.parent = groupNode;
+        const layoutGroup = layoutGroups.find((g) => g.id === group.getId());
+        if (layoutGroup) {
+          childGroups.push(layoutGroup);
+          layoutGroup.parent = groupNode;
         }
       });
       groupNode.groups = childGroups;
@@ -552,11 +577,20 @@ class BaseLayout implements Layout {
     return layoutGroups;
   }
 
-  protected initializeNewNodePositions(newNodes: LayoutNode[], graph: Graph): void {
-    const cx = graph.getBounds().width / 2;
-    const cy = graph.getBounds().height / 2;
+  protected initializeNodePositions(
+    newNodes: LayoutNode[],
+    graph: Graph,
+    force: boolean = false,
+  ): void {
+    const { width, height } = graph.getBounds();
+    const cx = width / 2;
+    const cy = height / 2;
     newNodes.forEach((node: LayoutNode) => {
-      node.setPosition(cx, cy);
+      // only init position for nodes that are still at 0, 0
+      const { x, y } = node.element.getPosition();
+      if (force || (x === 0 && y === 0)) {
+        node.setPosition(cx, cy);
+      }
     });
   }
 
@@ -590,8 +624,8 @@ class BaseLayout implements Layout {
     const prevGroups = this.groups;
 
     // create datum
-    const leafNodes = leafNodeElements(this.graph.getNodes());
-    const groups = groupNodeElements(this.graph.getNodes());
+    const leafNodes = leafNodeElements(this.graph.getNodes()).filter((n) => n.isVisible());
+    const groups = groupNodeElements(this.graph.getNodes()).filter((g) => g.isVisible());
 
     this.nodes = this.getNodes(leafNodes, this.options.nodeDistance);
 
@@ -631,7 +665,7 @@ class BaseLayout implements Layout {
     this.edges = this.getLinks(this.graph.getEdges());
 
     // initialize new node positions
-    this.initializeNewNodePositions(newNodes, this.graph);
+    this.initializeNodePositions(newNodes, this.graph, initialRun);
 
     // re-create the nodes map
     this.nodesMap = this.nodes.reduce((acc, n) => {
