@@ -1,5 +1,6 @@
 import { ComponentType } from 'react';
 import Point from './geom/Point';
+import Dimensions from './geom/Dimensions';
 import Rect from './geom/Rect';
 import { Padding, Translatable } from './geom/types';
 
@@ -64,11 +65,17 @@ export interface EdgeModel extends ElementModel {
   bendpoints?: PointTuple[];
 }
 
+// Scale extent: [min scale, max scale]
+export type ScaleExtent = [number, number];
+
 export interface GraphModel extends ElementModel {
   layout?: string;
   x?: number;
   y?: number;
   scale?: number;
+  scaleExtent?: ScaleExtent;
+  maxScale?: number;
+  layers?: string[];
 }
 
 export interface Anchor {
@@ -77,6 +84,7 @@ export interface Anchor {
 }
 
 export interface GraphElement<E extends ElementModel = ElementModel, D = any> extends WithState {
+  destroy(): void;
   getKind(): ModelKind;
   getLabel(): string;
   setLabel(label: string): void;
@@ -113,10 +121,15 @@ export interface Node<E extends NodeModel = NodeModel, D = any> extends GraphEle
   getAnchor(end: AnchorEnd, type?: string): Anchor;
   setAnchor(anchor: Anchor, end?: AnchorEnd, type?: string): void;
   getNodes(): Node[];
-  // TODO return an immutable rect
+  // TODO return an immutable bounds, position, dimensions?
   getBounds(): Rect;
   setBounds(bounds: Rect): void;
+  getPosition(): Point;
+  setPosition(location: Point): void;
+  getDimensions(): Dimensions;
+  setDimensions(dimensions: Dimensions): void;
   isGroup(): boolean;
+  setGroup(group: boolean): void;
   isCollapsed(): boolean;
   setCollapsed(collapsed: boolean): void;
   getNodeShape(): NodeShape;
@@ -146,17 +159,25 @@ export interface Graph<E extends GraphModel = GraphModel, D = any> extends Graph
   getEdges(): Edge[];
   getBounds(): Rect;
   setBounds(bounds: Rect): void;
+  getPosition(): Point;
+  setPosition(location: Point): void;
+  getDimensions(): Dimensions;
+  setDimensions(dimensions: Dimensions): void;
+  getScaleExtent(): ScaleExtent;
+  setScaleExtent(scaleExtent: ScaleExtent): void;
   getScale(): number;
   setScale(scale: number): void;
   getLayout(): string | undefined;
   setLayout(type: string | undefined): void;
   layout(): void;
+  getLayers(): string[];
+  setLayers(layers: string[]): void;
 
   // viewport operations
   reset(): void;
   scaleBy(scale: number, location?: Point): void;
   fit(padding?: number): void;
-  panIntoView(element: Node, options: { offset?: number; minimumVisible?: number }): void;
+  panIntoView(element: Node, options?: { offset?: number; minimumVisible?: number }): void;
 }
 
 export const isGraph = (element: GraphElement): element is Graph => {
@@ -210,14 +231,18 @@ export interface Controller extends WithState {
   getElements(): GraphElement[];
 }
 
-type ElementEvent = { target: GraphElement };
+export type ElementEvent = { target: GraphElement };
+export type ElementVisibilityChangeEvent = ElementEvent & { visible: boolean };
+
 export type ElementChildEventListener = EventListener<[ElementEvent & { child: GraphElement }]>;
+export type ElementVisibilityChangeEventListener = EventListener<[ElementVisibilityChangeEvent]>;
 
 export type NodeCollapseChangeEventListener = EventListener<[{ node: Node }]>;
 
 export type GraphLayoutEndEventListener = EventListener<[{ graph: Graph }]>;
 
 export const ADD_CHILD_EVENT = 'element-add-child';
+export const ELEMENT_VISIBILITY_CHANGE_EVENT = 'element-visibility-change';
 export const REMOVE_CHILD_EVENT = 'element-remove-child';
 export const NODE_COLLAPSE_CHANGE_EVENT = 'node-collapse-change';
 export const GRAPH_LAYOUT_END_EVENT = 'graph-layout-end';
