@@ -15,7 +15,7 @@ import {
   K8sKind,
 } from '../module/k8s';
 import { cloneBuild, formatBuildDuration, getBuildNumber } from '../module/k8s/builds';
-import { DetailsPage, ListPage, Table, TableRow, TableData } from './factory';
+import { DetailsPage, ListPage, Table, TableRow, TableData, RowFunction } from './factory';
 import { errorModal, confirmModal } from './modals';
 import {
   AsyncComponent,
@@ -38,7 +38,6 @@ import {
   Timestamp,
 } from './utils';
 import { BuildPipeline, BuildPipelineLogLink } from './build-pipeline';
-import { fromNow } from './utils/datetime';
 import { BuildLogs } from './build-logs';
 import { ResourceEventStream } from './events';
 import { Area, requirePrometheus } from './graphs';
@@ -346,7 +345,7 @@ const BuildsTableHeader = () => {
 };
 BuildsTableHeader.displayName = 'BuildsTableHeader';
 
-const BuildsTableRow: React.FC<BuildsTableRowProps> = ({ obj, index, key, style }) => {
+const BuildsTableRow: RowFunction<K8sResourceKind> = ({ obj, index, key, style }) => {
   return (
     <TableRow id={obj.metadata.uid} index={index} trKey={key} style={style}>
       <TableData className={tableColumnClasses[0]}>
@@ -364,7 +363,7 @@ const BuildsTableRow: React.FC<BuildsTableRowProps> = ({ obj, index, key, style
         <Status status={obj.status.phase} />
       </TableData>
       <TableData className={tableColumnClasses[3]}>
-        {fromNow(obj.metadata.creationTimestamp)}
+        <Timestamp timestamp={obj.metadata.creationTimestamp} />
       </TableData>
       <TableData className={tableColumnClasses[4]}>
         <ResourceKebab actions={menuActions} kind={BuildsReference} resource={obj} />
@@ -372,13 +371,6 @@ const BuildsTableRow: React.FC<BuildsTableRowProps> = ({ obj, index, key, style
     </TableRow>
   );
 };
-BuildsTableRow.displayName = 'BuildsTableRow';
-type BuildsTableRowProps = {
-  obj: K8sResourceKind;
-  index: number;
-  key?: string;
-  style: object;
-};
 
 export const BuildsList: React.SFC = (props) => (
   <Table
@@ -397,8 +389,8 @@ export const buildPhase = (build) => build.status.phase;
 const allPhases = ['New', 'Pending', 'Running', 'Complete', 'Failed', 'Error', 'Cancelled'];
 const filters = [
   {
+    filterGroupName: 'Status',
     type: 'build-status',
-    selected: allPhases,
     reducer: buildPhase,
     items: _.map(allPhases, (phase) => ({
       id: phase,
