@@ -12,7 +12,6 @@ import { ResourceListDropdown } from './resource-dropdown';
 import { TextFilter } from './factory';
 import {
   apiGroupForReference,
-  groupVersionFor,
   isGroupVersionKind,
   kindForReference,
   referenceFor,
@@ -66,16 +65,21 @@ const kindFilter = (reference, { involvedObject }) => {
   }
   const kinds = reference.split(',');
   return kinds.some((ref) => {
-    if (isGroupVersionKind(ref)) {
-      const group = apiGroupForReference(ref);
-      const kind = kindForReference(ref);
-      if (typeof involvedObject.apiVersion === 'undefined') {
-        return false;
-      }
-      const { group: eventGroup } = groupVersionFor(involvedObject.apiVersion);
-      return involvedObject.kind === kind && eventGroup === group;
+    if (!isGroupVersionKind(ref)) {
+      return involvedObject.kind === ref;
     }
-    return involvedObject.kind === ref;
+    // Use `referenceFor` to resolve `apiVersion` when missing from `involvedObject`.
+    // We need `apiVersion` to get the group.
+    const involvedObjectRef = referenceFor(involvedObject);
+    if (!involvedObjectRef) {
+      return false;
+    }
+    // Only check the group and kind, not the API version, so that we catch
+    // events for the same resource under a different API version.
+    return (
+      involvedObject.kind === kindForReference(ref) &&
+      apiGroupForReference(involvedObjectRef) === apiGroupForReference(ref)
+    );
   });
 };
 
@@ -96,7 +100,7 @@ const Inner = connectToFlags(FLAGS.CAN_LIST_NODE)(
             <i className="co-sysevent-icon" title={tooltipMsg} />
             <div className="co-sysevent__icon-line" />
           </div>
-          <div className="co-sysevent__box">
+          <div className="co-sysevent__box" role="gridcell">
             <div className="co-sysevent__header">
               <div className="co-sysevent__subheader">
                 <ResourceLink
@@ -205,7 +209,7 @@ export class EventsList extends React.Component {
             <TextFilter
               autoFocus={autoFocus}
               label="Events by name or message"
-              onChange={(e) => this.setState({ textFilter: e.target.value || '' })}
+              onChange={(val) => this.setState({ textFilter: val || '' })}
             />
           </div>
           <div className="form-group">
@@ -335,19 +339,15 @@ class EventStream extends React.Component {
         this.flushMessages();
       })
       .onopen(() => {
-        this.messages = {};
-        this.setState({ error: false, loading: false, sortedMessages: [], filteredEvents: [] });
+        this.setState({ error: false, loading: false });
       })
       .onclose((evt) => {
         if (evt && evt.wasClean === false) {
           this.setState({ error: evt.reason || 'Connection did not close cleanly.' });
         }
-        this.messages = {};
-        this.setState({ sortedMessages: [], filteredEvents: [] });
       })
       .onerror(() => {
-        this.messages = {};
-        this.setState({ error: true, sortedMessages: [], filteredEvents: [] });
+        this.setState({ error: true });
       });
   }
 
