@@ -4,15 +4,13 @@ import * as React from 'react';
 import { connect } from 'react-redux';
 import { Link } from 'react-router-dom';
 
-import { FLAGS } from '@console/internal/const';
+import { FLAGS } from '@console/shared';
 import { featureReducerName } from '../../reducers/features';
-import { MonitoringRoutes } from '../../reducers/monitoring';
-import { getActivePerspective } from '../../reducers/ui';
+import { getActivePerspective, getActiveNamespace } from '../../reducers/ui';
 import { RootState } from '../../redux';
 
-export const getPrometheusExpressionBrowserURL = (urls, queries): string => {
-  const base = urls && urls[MonitoringRoutes.Prometheus];
-  if (!base || _.isEmpty(queries)) {
+export const getPrometheusExpressionBrowserURL = (url, queries): string => {
+  if (!url || _.isEmpty(queries)) {
     return null;
   }
   const params = new URLSearchParams();
@@ -21,13 +19,14 @@ export const getPrometheusExpressionBrowserURL = (urls, queries): string => {
     params.set(`g${i}.expr`, query);
     params.set(`g${i}.tab`, '0');
   });
-  return `${base}/graph?${params.toString()}`;
+  return `${url}/graph?${params.toString()}`;
 };
 
 const mapStateToProps = (state: RootState) => ({
   canAccessMonitoring:
     !!state[featureReducerName].get(FLAGS.CAN_GET_NS) && !!window.SERVER_FLAGS.prometheusBaseURL,
   perspective: getActivePerspective(state),
+  namespace: getActiveNamespace(state),
 });
 
 export const PrometheusGraphLink_: React.FC<PrometheusGraphLinkProps> = ({
@@ -35,6 +34,7 @@ export const PrometheusGraphLink_: React.FC<PrometheusGraphLinkProps> = ({
   children,
   perspective,
   query,
+  namespace,
 }) => {
   if (!query) {
     return <>{children}</>;
@@ -46,7 +46,7 @@ export const PrometheusGraphLink_: React.FC<PrometheusGraphLinkProps> = ({
   const url =
     canAccessMonitoring && perspective === 'admin'
       ? `/monitoring/query-browser?${params.toString()}`
-      : `/metrics?${params.toString()}`;
+      : `/dev-monitoring/ns/${namespace}/metrics?${params.toString()}`;
 
   return (
     <Link to={url} style={{ color: 'inherit', textDecoration: 'none' }}>
@@ -58,7 +58,7 @@ export const PrometheusGraphLink = connect(mapStateToProps)(PrometheusGraphLink_
 
 export const PrometheusGraph: React.FC<PrometheusGraphProps> = React.forwardRef(
   ({ children, className, title }, ref: React.RefObject<HTMLDivElement>) => (
-    <div ref={ref} className={classNames('graph-wrapper', className)}>
+    <div ref={ref} className={classNames('graph-wrapper graph-wrapper__horizontal-bar', className)}>
       {title && <h5 className="graph-title">{title}</h5>}
       {children}
     </div>
@@ -69,6 +69,7 @@ type PrometheusGraphLinkProps = {
   canAccessMonitoring: boolean;
   perspective: string;
   query: string;
+  namespace?: string;
 };
 
 type PrometheusGraphProps = {
