@@ -3,7 +3,7 @@ import * as _ from 'lodash-es';
 import { PrometheusResponse, DataPoint } from '.';
 import { Humanize } from '../utils';
 
-export const getRangeVectorStats: GetStats = (response) => {
+export const getRangeVectorStats: GetStats<Date> = (response) => {
   const values = _.get(response, 'data.result[0].values');
   return _.map(values, (value) => ({
     x: new Date(value[0] * 1000),
@@ -11,7 +11,7 @@ export const getRangeVectorStats: GetStats = (response) => {
   }));
 };
 
-export const getInstantVectorStats: GetStats = (response, metric, humanize) => {
+export const getInstantVectorStats: GetStats<number> = (response, metric, humanize) => {
   const results = _.get(response, 'data.result', []);
   return results.map((r) => {
     const y = parseFloat(_.get(r, 'value[1]'));
@@ -24,6 +24,6 @@ export const getInstantVectorStats: GetStats = (response, metric, humanize) => {
   });
 };
 
-export type GetStats = {
-  (response: PrometheusResponse, metric?: string, humanize?: Humanize): DataPoint[];
+export type GetStats<X = Date | number | string> = {
+  (response: PrometheusResponse, metric?: string, humanize?: Humanize): DataPoint<X>[];
 };
