@@ -5,9 +5,9 @@ import * as classNames from 'classnames';
 import { sortable } from '@patternfly/react-table';
 
 import { Status } from '@console/shared';
-import { getJobTypeAndCompletions, K8sKind, JobKind } from '../module/k8s';
+import { getJobTypeAndCompletions, K8sKind, JobKind, K8sResourceKind } from '../module/k8s';
 import { Conditions } from './conditions';
-import { DetailsPage, ListPage, Table, TableRow, TableData } from './factory';
+import { DetailsPage, ListPage, Table, TableRow, TableData, RowFunction } from './factory';
 import { configureJobParallelismModal } from './modals';
 import {
   ContainerTable,
@@ -15,6 +15,7 @@ import {
   Kebab,
   KebabAction,
   LabelList,
+  PodsComponent,
   ResourceKebab,
   ResourceLink,
   ResourceSummary,
@@ -98,17 +99,7 @@ const JobTableHeader = () => {
 };
 JobTableHeader.displayName = 'JobTableHeader';
 
-const JobTableRow = ({
-  obj: job,
-  index,
-  key,
-  style,
-}: {
-  obj: JobKind;
-  index: number;
-  key: string;
-  style: any;
-}) => {
+const JobTableRow: RowFunction<JobKind> = ({ obj: job, index, key, style }) => {
   const { type, completions } = getJobTypeAndCompletions(job);
   return (
     <TableRow id={job.metadata.uid} index={index} trKey={key} style={style}>
@@ -142,7 +133,6 @@ const JobTableRow = ({
     </TableRow>
   );
 };
-JobTableRow.displayName = 'JobTableRow';
 
 const jobStatus = (job: JobKind): string => {
   return job && job.status ? _.get(job, 'status.conditions[0].type', 'In Progress') : null;
@@ -204,6 +194,10 @@ const JobDetails: React.FC<JobsDetailsProps> = ({ obj: job }) => (
   </>
 );
 
+const JobPods: React.FC<JobPodsProps> = (props) => (
+  <PodsComponent {...props} customData={{ showNodes: true }} />
+);
+
 const { details, pods, editYaml, events } = navFactory;
 const JobsDetailsPage: React.FC<JobsDetailsPageProps> = (props) => (
   <DetailsPage
@@ -211,7 +205,7 @@ const JobsDetailsPage: React.FC<JobsDetailsPageProps> = (props) => (
     getResourceStatus={jobStatus}
     kind={kind}
     menuActions={menuActions}
-    pages={[details(JobDetails), editYaml(), pods(), events(ResourceEventStream)]}
+    pages={[details(JobDetails), editYaml(), pods(JobPods), events(ResourceEventStream)]}
   />
 );
 const JobsList: React.FC = (props) => (
@@ -239,6 +233,10 @@ type JobsPageProps = {
   selector?: any;
 };
 
+type JobPodsProps = {
+  obj: K8sResourceKind;
+};
+
 type JobsDetailsPageProps = {
   match: any;
 };
