@@ -39,6 +39,11 @@ const TYPES = {
     space: true,
     divisor: 1000,
   },
+  packetsPerSec: {
+    units: ['pps', 'kpps'],
+    space: true,
+    divisor: 1000,
+  },
   seconds: {
     units: ['ns', 'μs', 'ms', 's'],
     space: true,
@@ -207,6 +212,8 @@ export const humanizeDecimalBytes = (v, initialUnit, preferredUnit) =>
   humanize(v, 'decimalBytes', true, initialUnit, preferredUnit);
 export const humanizeDecimalBytesPerSec = (v, initialUnit, preferredUnit) =>
   humanize(v, 'decimalBytesPerSec', true, initialUnit, preferredUnit);
+export const humanizePacketsPerSec = (v, initialUnit, preferredUnit) =>
+  humanize(v, 'packetsPerSec', true, initialUnit, preferredUnit);
 export const humanizeNumber = (v, initialUnit, preferredUnit) =>
   humanize(v, 'numeric', true, initialUnit, preferredUnit);
 export const humanizeNumberSI = (v, initialUnit, preferredUnit) =>
@@ -387,3 +394,16 @@ export const secondsToNanoSeconds = (value) => {
   const val = Number(value);
   return Number.isFinite(val) ? val * 1000 ** 3 : 0;
 };
+
+export const formatToFractionalDigits = (value, digits) =>
+  Intl.NumberFormat(undefined, {
+    minimumFractionDigits: digits,
+    maximumFractionDigits: digits,
+  }).format(value);
+
+export const formatBytesAsMiB = (bytes) => {
+  const mib = bytes / 1024 / 1024;
+  return formatToFractionalDigits(mib, 1);
+};
+
+export const formatCores = (cores) => formatToFractionalDigits(cores, 3);
